@@ -3,7 +3,7 @@
 **
 **	(c) COPYRIGHT MIT 1995.
 **	Please first read the full copyright statement in the file COPYRIGH.
-**	@(#) $Id: HTMIME.c,v 2.97.4.1.2.1 2000/06/19 15:37:48 kahan Exp $
+**	@(#) $Id: HTMIME.c,v 2.100.2.1 2001/08/30 13:57:59 kahan Exp $
 **
 **	This is RFC 1341-specific code.
 **	The input stream pushed into this parser is assumed to be
@@ -232,14 +232,13 @@ PRIVATE int pumpData (HTStream * me)
     return HT_OK;
 }
 
-/* _dispatchParsers - call request's MIME header parser.
-** Use global parser if no appropriate one is found for request.
+/* _dispatchParsers
+ * call request's MIME header parser. Use global parser if no 
+ * appropriate one is found for request.
 */
-PRIVATE int _dispatchParsers (HTStream * me)
+PRIVATE int _dispatchParsers (HTRequest * req, char * token, char * value)
 {
     int status;
-    char * token = HTChunk_data(me->token);
-    char * value = HTChunk_data(me->value);
     BOOL found = NO;
     BOOL local = NO;
     HTMIMEParseSet * parseSet;
@@ -250,30 +249,49 @@ PRIVATE int _dispatchParsers (HTStream * me)
 			      value ? value : "<null>");
     if (!token) return HT_OK;			    /* Ignore noop token */
 
+    /*
+    ** Search the local set of MIME parsers
+    */
+    if ((parseSet = HTRequest_MIMEParseSet(req, &local)) != NULL) {
+        status = HTMIMEParseSet_dispatch(parseSet, req, 
+					 token, value, &found);
+	if (found) return status;
+    }
+
+    /*
+    ** Search the global set of MIME parsers
+    */
+    if (local==NO && (parseSet = HTHeader_MIMEParseSet()) != NULL) {
+	status = HTMIMEParseSet_dispatch(parseSet, req, 
+					 token, value, &found);
+	if (found) return status;
+    }
+
+    return HT_OK;
+}
+
+/* _stream2dispatchParsers - extracts the arguments from a
+ * MIME stream before calling the generic _dispatchParser
+ * function.
+ */
+PRIVATE int _stream2dispatchParsers (HTStream * me)
+{
+    char * token = HTChunk_data(me->token);
+    char * value = HTChunk_data(me->value);
+
+    /* In case we get an empty header consisting of a CRLF, we fall thru */
+    HTTRACE(STREAM_TRACE, "MIME header. %s: %s\n" _ 
+			      token ? token : "<null>" _ 
+			      value ? value : "<null>");
+    if (!token) return HT_OK;			    /* Ignore noop token */
+
     /*
     ** Remember the original header
     */
     HTResponse_addHeader(me->response, token, value);
 
-    /*
-    ** Search the local set of MIME parsers
-    */
-    if ((parseSet = HTRequest_MIMEParseSet(me->request, &local)) != NULL) {
-        status = HTMIMEParseSet_dispatch(parseSet, me->request, 
-					 token, value, &found);
-	if (found) return status;
-    }
-
-    /*
-    ** Search the global set of MIME parsers
-    */
-    if (local==NO && (parseSet = HTHeader_MIMEParseSet()) != NULL) {
-	status = HTMIMEParseSet_dispatch(parseSet, me->request, 
-					 token, value, &found);
-	if (found) return status;
-    }
-
-    return HT_OK;
+    /* call the parsers to set the headers */
+    return (_dispatchParsers (me->request, token, value));
 }
 
 /*
@@ -340,7 +358,7 @@ PRIVATE int HTMIME_put_block (HTStream * me, const char * b, int l)
 		int ret = HT_ERROR;
 		HTChunk_putb(me->value, value, end-value);
 		HTChunk_putc(me->value, '\0');
-		ret = _dispatchParsers(me);
+		ret =  _stream2dispatchParsers(me);
 		HTNet_addBytesRead(me->net, b-start);
 		start=b, end=b;
 		if (me->EOLstate == EOL_END) {		/* EOL_END */
@@ -356,8 +374,8 @@ PRIVATE int HTMIME_put_block (HTStream * me, const char * b, int l)
                         }
 		    }
 	        } else {				/* EOL_LINE */
-		    HTChunk_clear(me->token);
-		    HTChunk_clear(me->value);
+		    HTChunk_truncate(me->token,0);
+		    HTChunk_truncate(me->value,0);
 		    me->haveToken = NO;
 		    me->hash = 0;
 		    value = NULL;
@@ -474,7 +492,7 @@ PRIVATE int HTMIME_free (HTStream * me)
 {
     int status = HT_OK;
     if (!me->transparent)
-        if (_dispatchParsers(me) == HT_OK)
+        if (_stream2dispatchParsers(me) == HT_OK)
 	    pumpData(me);
     if (me->target) {
 	if ((status = (*me->target->isa->_free)(me->target))==HT_WOULD_BLOCK)
@@ -761,3 +779,58 @@ PUBLIC HTConverter * HTMIME_saveStream (void)
 {
     return LocalSaveStream;
 }
+
+#ifndef NO_CACHE
+/* HTMIME_anchor2response
+ * Copies the anchor HTTP headers into a response object by means
+ * of the generic _dispatchParsers function. Written so that we can
+ * copy the HTTP headers stored in the cache to the response object.
+ */
+PRIVATE void HTMIME_anchor2response (HTRequest * req)
+{
+  char * token;
+  char * value;
+  HTAssocList * header;
+  HTAssoc * pres;
+  HTResponse * res;
+  HTParentAnchor * anchor;
+
+  if (!req)
+    return;
+  
+  anchor = HTRequest_anchor (req);
+  header = HTAnchor_header (anchor);
+  if (!anchor || !header)
+    return;
+
+  while ((pres = (HTAssoc *) HTAssocList_nextObject (header)))
+    {
+      token = HTAssoc_name (pres);
+      value = HTAssoc_value (pres);
+      _dispatchParsers (req, token, value);
+    }
+  
+  /*
+  **  Notify the response object not to delete the lists that we
+  **  have inherited from the anchor object
+  */
+  res = HTRequest_response (req);
+  HTResponse_isCached (res, YES);  
+}
+
+/*
+**	A small AFTER filter that is a frontend to the 
+**      HTMIME_anchor2headers function.
+*/
+
+PUBLIC HTStream * HTCacheCopyHeaders   (HTRequest *	request,
+					void *		param,
+					HTFormat	input_format,
+					HTFormat	output_format,
+					HTStream *	output_stream)
+{
+    HTTRACE(STREAM_TRACE, "Cache Copy Headers.. Copying headers into the response object\n");
+    HTMIME_anchor2response (request);
+    return HT_OK;
+}
+#endif /* NO_CACHE */
