@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT MIT and INRIA, 1996.
+ *  (c) COPYRIGHT MIT and INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -23,13 +23,14 @@
 /* a record in an history */
 typedef struct _HistElement
 {
-     STRING HistUrl;        /* document URL */
-     STRING form_data;      /* data associated with forms */
-     int    method;         /* method used to request this URL */
-     int    HistPosition;	/* volume preceding the first element to be
-                               made visible in the main window */
-     int    HistDistance;	/* distance from the  top of the window to the
-                               top of this element (% of the window height) */
+  char  *HistUrl;        /* document URL */
+  char  *HistInitialUrl; /* document URL */
+  char  *form_data;      /* data associated with forms */
+  int    method;         /* method used to request this URL */
+  int    HistPosition;	/* volume preceding the first element to be
+			   made visible in the main window */
+  int    HistDistance;	/* distance from the  top of the window to the
+			   top of this element (% of the window height) */
 } HistElement;
 
 /* the history of a window */
@@ -43,6 +44,7 @@ typedef struct _GotoHistory_context
   int                  prevnext;
   ThotBool	       last;
   ThotBool             next_doc_loaded;
+  char                *initial_url;
 } GotoHistory_context;
 
 /* the history of all windows */
@@ -54,13 +56,7 @@ static int          DocHistoryIndex[DocumentTableLength];
    InitDocHistory
    Reset history for document doc
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                InitDocHistory (Document doc)
-#else
-void                InitDocHistory (doc)
-Document            document;
-
-#endif
 {
    DocHistoryIndex[doc] = -1;
 }
@@ -87,13 +83,7 @@ void                FreeDocHistory ()
   ElementAtPosition
   Returns the element that is at position pos in document doc.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 Element       	ElementAtPosition (Document doc, int pos)
-#else  /* __STDC__ */
-Element       	ElementAtPosition (doc, pos)
-   Document	doc;
-   int		pos;
-#endif /* __STDC__ */
 {
    Element	el, result, child, next;
    int		sum, vol;
@@ -120,7 +110,7 @@ Element       	ElementAtPosition (doc, pos)
 	     vol = TtaGetElementVolume (el);
 	     if (sum + vol <= pos)
 	        {
-	next = el;
+		next = el;
 	        TtaNextSibling (&next);
 		if (next == NULL)
 		  stop = TRUE;
@@ -156,13 +146,7 @@ Element       	ElementAtPosition (doc, pos)
   Returns the position of the first visible element in the main view of
   document doc.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 int             RelativePosition (Document doc, int *distance)
-#else  /* __STDC__ */
-int             RelativePosition (doc, distance)
-   Document	doc;
-   int		*distance;
-#endif /* __STDC__ */
 {
    int		sum;
    Element	el, sibling, ancestor;
@@ -190,32 +174,26 @@ int             RelativePosition (doc, distance)
   A IsDocumentLoaded frontend which returns TRUE if a given URL is already
   being displayed in another window. 
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static ThotBool IsNextDocLoaded (const Document baseDoc, const STRING url, const STRING form_data, const ClickEvent CE_event)
-#else
-static ThotBool IsNextDocLoaded (Document baseDoc, url, form_data, CE_event)
-STRING url;
-STRING form_data;
-ClickEvent  CE_event;
-#endif
+static ThotBool IsNextDocLoaded (const Document baseDoc, const char *url,
+				 const char *form_data, const ClickEvent CE_event)
 {
-  STRING              tempdocument;
-  STRING              target;
-  STRING              documentname;
-  STRING              parameters;
-  STRING              pathname;
-  ThotBool loaded;
+  char              *tempdocument;
+  char              *target;
+  char              *documentname;
+  char              *parameters;
+  char              *pathname;
+  ThotBool           loaded;
 
-  if (url == (STRING) NULL)
+  if (url == NULL)
     return FALSE;
 
-  tempdocument = TtaAllocString (MAX_LENGTH);
-  target = TtaAllocString (MAX_LENGTH);
-  documentname = TtaAllocString (MAX_LENGTH);
-  parameters = TtaAllocString (MAX_LENGTH);
-  pathname = TtaAllocString (MAX_LENGTH);
+  tempdocument = TtaGetMemory (MAX_LENGTH);
+  target = TtaGetMemory (MAX_LENGTH);
+  documentname = TtaGetMemory (MAX_LENGTH);
+  parameters = TtaGetMemory (MAX_LENGTH);
+  pathname = TtaGetMemory (MAX_LENGTH);
 
-  ustrcpy (tempdocument, url);
+  strcpy (tempdocument, (char *) url);
   ExtractParameters (tempdocument, parameters);
   /* Extract the target if necessary */
   ExtractTarget (tempdocument, target);
@@ -227,7 +205,23 @@ ClickEvent  CE_event;
   else
     NormalizeURL (tempdocument, 0, pathname, documentname, NULL);
 
-  loaded = IsDocumentLoaded (pathname, form_data);
+   /* check if the user is already browsing the document in another window */
+   if (CE_event == CE_FORM_GET || CE_event == CE_FORM_POST)
+     {
+       loaded = IsDocumentLoaded (pathname, (char *) form_data);
+       /* we don't concatenate the new parameters as we give preference
+	  to the form data */
+     }
+   else
+     {
+       /* concatenate the parameters before making the test */
+       if (parameters[0] != EOS)
+	 {
+	   strcat (pathname, "?");
+	   strcat (pathname, parameters);
+	 }
+       loaded = IsDocumentLoaded (pathname, NULL);
+     }
 
   TtaFreeMemory (pathname);
   TtaFreeMemory (tempdocument);
@@ -242,23 +236,9 @@ ClickEvent  CE_event;
    GotoPreviousHTML_callback
    This function is called when the document is loaded
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void               GotoPreviousHTML_callback (int newdoc, int status, 
-					      STRING urlName,
-					      STRING outputfile, 
-					      AHTHeaders *http_headers,
-					      void * context)
-#else  /* __STDC__ */
-void               GotoPreviousHTML_callback (newdoc, status, urlName,
-                                             outputfile, http_headers,
-                                             context)
-int newdoc;
-int status;
-STRING urlName;
-STRING outputfile;
-AHTHeaders *http_headers;
-void *context;
-#endif
+void GotoPreviousHTML_callback (int newdoc, int status, char *urlName,
+				char *outputfile, AHTHeaders *http_headers,
+				void * context)
 {
   Document             doc;
   Element	       el;
@@ -281,6 +261,10 @@ void *context;
       if (ctx->last)
 	SetArrowButton (doc, FALSE, TRUE);
     }
+  if (!DocumentMeta[doc]->initial_url)
+    DocumentMeta[doc]->initial_url = ctx->initial_url;
+  else
+    TtaFreeMemory (ctx->initial_url);
   TtaFreeMemory (ctx);
 }
 
@@ -288,22 +272,18 @@ void *context;
    GotoPreviousHTML
    This function is called when the user presses the Previous button
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                GotoPreviousHTML (Document doc, View view)
-#else
-void                GotoPreviousHTML (doc, view)
-Document            document;
-View                view;
-#endif
+void  GotoPreviousHTML (Document doc, View view)
 {
    GotoHistory_context *ctx;
-   STRING              url = NULL;
-   STRING              form_data = NULL;
-   int                 prev, i;
-   int                 method;
-   ThotBool	       last, hist;
-   ThotBool            same_form_data;
-   ThotBool            next_doc_loaded = FALSE;
+   char                *url = NULL;
+   char                *initial_url = NULL;
+   char                *form_data = NULL;
+   int                  prev, i;
+   int                  method;
+   ThotBool	        last = FALSE;
+   ThotBool             hist = FALSE;
+   ThotBool             same_form_data;
+   ThotBool             next_doc_loaded = FALSE;
 
    if (doc < 0 || doc >= DocumentTableLength)
       return;
@@ -323,6 +303,7 @@ View                view;
 
    /* get the previous document information*/
    url = DocHistory[doc][prev].HistUrl;
+   initial_url = DocHistory[doc][prev].HistInitialUrl;
    form_data = DocHistory[doc][prev].form_data;
    method = DocHistory[doc][prev].method;
 
@@ -330,35 +311,41 @@ View                view;
    if (!form_data && (!DocumentMeta[doc]  || !DocumentMeta[doc]->form_data))
      same_form_data = TRUE;
    else if (form_data && DocumentMeta[doc] && DocumentMeta[doc]->form_data 
-	    && (!ustrcmp (form_data, DocumentMeta[doc]->form_data)))
+	    && (!strcmp (form_data, DocumentMeta[doc]->form_data)))
      same_form_data = TRUE;
    else
      same_form_data = FALSE;
 
    /* if the document has been edited, ask the user to confirm, except
       if it's simply a jump in the same document */
-   if (DocumentURLs[doc] != NULL)
+   if (DocumentURLs[doc] &&
+       (strcmp(DocumentURLs[doc], url) || !same_form_data))
      {
-       if (ustrcmp(DocumentURLs[doc], url)
-	   || !same_form_data)
-	 {
-	   /* is the next document already loaded? */
-	   next_doc_loaded = IsNextDocLoaded (doc, url, form_data, method);
-	   if (!next_doc_loaded && !CanReplaceCurrentDocument (doc, view))
-	     return;
-	 }
+       /* is the next document already loaded? */
+       next_doc_loaded = IsNextDocLoaded (doc, url, form_data, method);
+       if (!next_doc_loaded && !CanReplaceCurrentDocument (doc, view))
+	 return;
      }
 
 
    if (!next_doc_loaded)
      {
-       /* the current document must be put in the history if it's the last one */
-       hist = FALSE;
-       last = FALSE;
+       /* the current document must be put in the history if it's the last
+	  one */
        if (DocHistory[doc][DocHistoryIndex[doc]].HistUrl == NULL)
 	 {
-	   last = TRUE;
-	   hist = TRUE;
+	   if (DocumentURLs[doc] &&
+	       !IsW3Path (DocumentURLs[doc]) && !TtaFileExist (DocumentURLs[doc]))
+	     {
+	       /* cannot store the current document in the history */
+	       last = FALSE;
+	       hist = FALSE;
+	     }
+	   else
+	     {
+	       last = TRUE;
+	       hist = TRUE;
+	     }
 	 }
        else
 	 {
@@ -386,6 +373,7 @@ View                view;
    ctx->last = last;
    ctx->doc = doc;
    ctx->next_doc_loaded = next_doc_loaded;
+   ctx->initial_url = TtaStrdup (initial_url);
 
    /* 
    ** load (or jump to) the previous document 
@@ -394,13 +382,14 @@ View                view;
      {
      if (hist)
        /* record the current position in the history */
-       AddDocHistory (doc, DocumentURLs[doc], DocumentMeta[doc]->form_data, DocumentMeta[doc]->method);
+       AddDocHistory (doc, DocumentURLs[doc], DocumentMeta[doc]->initial_url,
+		      DocumentMeta[doc]->form_data, DocumentMeta[doc]->method);
      
      DocHistoryIndex[doc] = prev;
      }
 
    /* is it the current document ? */     
-   if (DocumentURLs[doc] && !ustrcmp (url, DocumentURLs[doc]) && same_form_data)
+   if (DocumentURLs[doc] && !strcmp (url, DocumentURLs[doc]) && same_form_data)
      {
        /* it's just a move in the same document */
        GotoPreviousHTML_callback (doc, 0, url, NULL, NULL, (void *) ctx);
@@ -416,23 +405,9 @@ View                view;
    GotoNextHTML_callback
    This function is called when the document is loaded
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void               GotoNextHTML_callback (int newdoc, int status, 
-					      STRING urlName,
-					      STRING outputfile, 
-					      AHTHeaders *http_headers,
-					      void * context)
-#else  /* __STDC__ */
-void               GotoNextHTML_callback (newdoc, status, urlName,
-                                             outputfile, http_headers,
-                                             context)
-int newdoc;
-int status;
-STRING urlName;
-STRING outputfile;
-AHTHeaders *http_headers;
-void *context;
-#endif
+void GotoNextHTML_callback (int newdoc, int status, char *urlName,
+			    char *outputfile, AHTHeaders *http_headers,
+			    void * context)
 {
   Element	       el;
   Document             doc;
@@ -453,6 +428,10 @@ void *context;
       el = ElementAtPosition (doc, DocHistory[doc][next].HistPosition);
       TtaShowElement (doc, 1, el, DocHistory[doc][next].HistDistance);
     }
+  if (!DocumentMeta[doc]->initial_url)
+    DocumentMeta[doc]->initial_url = ctx->initial_url;
+  else
+    TtaFreeMemory (ctx->initial_url);
   TtaFreeMemory (ctx);
 }
 
@@ -460,21 +439,16 @@ void *context;
    GotoNextHTML
    This function is called when the user presses the Next button
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                GotoNextHTML (Document doc, View view)
-#else
-void                GotoNextHTML (doc, view)
-Document            document;
-View                view;
-#endif
 {
    GotoHistory_context  *ctx;
-   STRING        url = NULL;
-   STRING        form_data = NULL;
-   int           method;
-   int		 next, i;
-   ThotBool      same_form_data;
-   ThotBool      next_doc_loaded = FALSE;
+   char                 *url = NULL;
+   char                 *initial_url = NULL;
+   char                 *form_data = NULL;
+   int                   method;
+   int		         next, i;
+   ThotBool              same_form_data;
+   ThotBool              next_doc_loaded = FALSE;
 
    if (doc < 0 || doc >= DocumentTableLength)
       return;
@@ -493,6 +467,7 @@ View                view;
 
    /* Get the next document information */
    url = DocHistory[doc][next].HistUrl;
+   initial_url = DocHistory[doc][next].HistInitialUrl;
    form_data = DocHistory[doc][next].form_data;
    method = DocHistory[doc][next].method;
 
@@ -500,23 +475,21 @@ View                view;
    if (!form_data && (!DocumentMeta[doc] || !DocumentMeta[doc]->form_data))
      same_form_data = TRUE;
    else if (form_data && DocumentMeta[doc] && DocumentMeta[doc]->form_data 
-	    && (!ustrcmp (form_data, DocumentMeta[doc]->form_data)))
+	    && (!strcmp (form_data, DocumentMeta[doc]->form_data)))
      same_form_data = TRUE;
    else
      same_form_data = FALSE;
 
    /* if the document has been edited, ask the user to confirm, except
       if it's simply a jump in the same document */
-   if (DocumentURLs[doc] != NULL)
+   if (DocumentURLs[doc] != NULL &&
+       (strcmp (DocumentURLs[doc], DocHistory[doc][next].HistUrl) ||
+	!same_form_data))
      {
-       if (ustrcmp (DocumentURLs[doc], DocHistory[doc][next].HistUrl)
-	   || !same_form_data)
-	 {
-	   /* is the next document already loaded? */
-	   next_doc_loaded = IsNextDocLoaded (doc, url, form_data, method);
-	   if (!CanReplaceCurrentDocument (doc, view))
-	     return;
-	 }
+       /* is the next document already loaded? */
+       next_doc_loaded = IsNextDocLoaded (doc, url, form_data, method);
+       if (!CanReplaceCurrentDocument (doc, view))
+	 return;
      }
 
    if (!next_doc_loaded)
@@ -553,9 +526,10 @@ View                view;
    ctx->prevnext = next;
    ctx->doc = doc;
    ctx->next_doc_loaded = next_doc_loaded;
+   ctx->initial_url = TtaStrdup (initial_url);
 
    /* is it the current document ? */
-   if (DocumentURLs[doc] && !ustrcmp (url, DocumentURLs[doc]) && same_form_data)
+   if (DocumentURLs[doc] && !strcmp (url, DocumentURLs[doc]) && same_form_data)
      /* it's just a move in the same document */
      GotoNextHTML_callback (doc, 0, url, NULL, NULL, (void *) ctx);
    else
@@ -569,26 +543,19 @@ View                view;
    AddDocHistory
    Add a new URL in the history associated with the window of document doc.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                AddDocHistory (Document doc, STRING url, STRING form_data, ClickEvent method)
-#else  /* __STDC__ */
-void                AddDocHistory (doc, url, form_data, method)
-Document	    doc;
-STRING              url;
-STRING              form_data;
-ClickEvent          method;
-
-#endif /* __STDC__ */
+void AddDocHistory (Document doc, char *url, char *initial_url,
+		    char *form_data, ClickEvent method)
 {
    int                 i, position, distance;
 
-   if (!url)
-      return;
-   if (*url == EOS)
+   if (!url || *url == EOS)
       return;
    /* avoid storing POST forms */
    if (method == CE_FORM_POST)
      return;
+   /* don't register a new document not saved */
+   if (!IsW3Path (url) && !TtaFileExist (url))
+     return;
    else if (method == CE_RELATIVE)
      /* All registered URLs are absolute */
      method = CE_ABSOLUTE;
@@ -618,11 +585,14 @@ ClickEvent          method;
    /* store the URL and the associated form data */
    if (DocHistory[doc][DocHistoryIndex[doc]].HistUrl)
      TtaFreeMemory (DocHistory[doc][DocHistoryIndex[doc]].HistUrl);
+   if (DocHistory[doc][DocHistoryIndex[doc]].HistInitialUrl)
+     TtaFreeMemory (DocHistory[doc][DocHistoryIndex[doc]].HistInitialUrl);
    if (DocHistory[doc][DocHistoryIndex[doc]].form_data)
      TtaFreeMemory (DocHistory[doc][DocHistoryIndex[doc]].form_data);
    
-   DocHistory[doc][DocHistoryIndex[doc]].HistUrl = TtaWCSdup (url);
-   DocHistory[doc][DocHistoryIndex[doc]].form_data = TtaWCSdup (form_data);
+   DocHistory[doc][DocHistoryIndex[doc]].HistUrl = TtaStrdup (url);
+   DocHistory[doc][DocHistoryIndex[doc]].HistInitialUrl = TtaStrdup (initial_url);
+   DocHistory[doc][DocHistoryIndex[doc]].form_data = TtaStrdup (form_data);
    DocHistory[doc][DocHistoryIndex[doc]].method = method;
 
    position = RelativePosition (doc, &distance);
@@ -635,13 +605,21 @@ ClickEvent          method;
    /* delete the next entry in the history */
    if (DocHistory[doc][DocHistoryIndex[doc]].HistUrl)
        TtaFreeMemory (DocHistory[doc][DocHistoryIndex[doc]].HistUrl);
+   if (DocHistory[doc][DocHistoryIndex[doc]].HistInitialUrl)
+       TtaFreeMemory (DocHistory[doc][DocHistoryIndex[doc]].HistInitialUrl);
+
    if (DocHistory[doc][DocHistoryIndex[doc]].form_data)
        TtaFreeMemory (DocHistory[doc][DocHistoryIndex[doc]].form_data);
 
    DocHistory[doc][DocHistoryIndex[doc]].HistUrl = NULL;
+   DocHistory[doc][DocHistoryIndex[doc]].HistInitialUrl = NULL;
    DocHistory[doc][DocHistoryIndex[doc]].form_data = NULL;
    DocHistory[doc][DocHistoryIndex[doc]].method = CE_ABSOLUTE;
 
    /* set the Forward button off */
    SetArrowButton (doc, FALSE, FALSE);
 }
+
+
+
+
