@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT MIT and INRIA, 1996.
+ *  (c) COPYRIGHT MIT and INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -15,20 +15,24 @@
 #define THOT_EXPORT extern
 #include "amaya.h"
 #include "css.h"
-
+#ifdef _SVG
+#include "SVG.h"
+#endif /* _SVG */
 #ifdef _WINDOWS
 #include "wininclude.h"
 #endif /* _WINDOWS */
 
 static int         CSScase;
-static CHAR_T*     CSSpath;
+static char       *CSSpath;
 static Document    CSSdocument;
 
 #include "AHTURLTools_f.h"
+#include "EDITstyle_f.h"
 #include "EDITORactions_f.h"
 #include "HTMLedit_f.h"
 #include "UIcss_f.h"
 #include "css_f.h"
+#include "dialog.h"
 #include "init_f.h"
 #include "query_f.h"
 #include "styleparser_f.h"
@@ -39,19 +43,13 @@ static Document    CSSdocument;
    When returning, the parameter completeURL contains the normalized url
    and the parameter localfile the path of the local copy of the file.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool        LoadRemoteStyleSheet (STRING url, Document doc, Element el, CSSInfoPtr css, STRING completeURL, STRING localfile)
-#else
-ThotBool        LoadRemoteStyleSheet (url, doc, el, css, completeURL, localfile)
-STRING          url;
-Document        doc;
-Element         el;
-CSSInfoPtr      css;
-#endif
+ThotBool  LoadRemoteStyleSheet (char *url, Document doc, Element el,
+				CSSInfoPtr css, char *completeURL,
+				char *localfile)
 {
   CSSInfoPtr          oldcss;
-  CHAR_T              tempname[MAX_LENGTH];
-  STRING              tempdocument = NULL;
+  char                tempname[MAX_LENGTH];
+  char               *tempdocument = NULL;
   int                 toparse;
   ThotBool            local = FALSE;
   ThotBool            import = (css != NULL);
@@ -70,14 +68,17 @@ CSSInfoPtr      css;
       /* check against double inclusion */
       oldcss = SearchCSS (0, completeURL);
       if (oldcss != NULL)
-	ustrcpy (localfile, oldcss->localName);
+	strcpy (localfile, oldcss->localName);
       else
 	{
 	  /* the document is not loaded yet */
 	  /* changed this to doc */
-	  toparse = GetObjectWWW (doc, completeURL, NULL, localfile, AMAYA_SYNC | AMAYA_LOAD_CSS, NULL, NULL, NULL, NULL, NO, NULL);
+	  toparse = GetObjectWWW (doc, completeURL, NULL, localfile,
+				  AMAYA_SYNC | AMAYA_LOAD_CSS, NULL, NULL,
+				  NULL, NULL, NO, NULL);
 	  if (toparse || localfile[0] == EOS || !TtaFileExist (localfile))
-	    TtaSetStatus (doc, 1, TtaGetMessage (AMAYA, AM_CANNOT_LOAD), completeURL);
+	    TtaSetStatus (doc, 1, TtaGetMessage (AMAYA, AM_CANNOT_LOAD),
+			  completeURL);
 	  else
 	    {
 	      /* store a copy of the remote CSS in .amaya/0 */
@@ -85,8 +86,8 @@ CSSInfoPtr      css;
 	      tempdocument = GetLocalPath (0, completeURL);
 	      TtaFileUnlink (tempdocument);
 	      /* now we can rename the local name of a remote document */
-	      urename (localfile, tempdocument);
-	      ustrcpy (localfile, tempdocument);
+	      rename (localfile, tempdocument);
+	      strcpy (localfile, tempdocument);
 	      TtaFreeMemory (tempdocument);
 	    }
 	}
@@ -97,7 +98,7 @@ CSSInfoPtr      css;
       /* store a copy of the local CSS in .amaya/0 */
       tempdocument = GetLocalPath (0, completeURL);
       local = FALSE;
-      ustrcpy (localfile, tempdocument);
+      strcpy (localfile, tempdocument);
       TtaFileCopy (completeURL, localfile);
       TtaFreeMemory (tempdocument);
     }
@@ -109,17 +110,12 @@ CSSInfoPtr      css;
    LoadUserStyleSheet : Load the user Style Sheet found in it's    
    home directory or the default one in THOTDIR.           
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                LoadUserStyleSheet (Document doc)
-#else
-void                LoadUserStyleSheet (doc)
-Document            doc;
-#endif
 {
   CSSInfoPtr          css;
   struct stat         buf;
   FILE               *res;
-  CHAR_T              *buffer, *ptr;
+  char               *buffer, *ptr;
   int                 len;
 
   /* look for the User preferences */
@@ -158,7 +154,7 @@ Document            doc;
   if (css->enabled[doc] && ptr[0] != EOS  && TtaFileExist (ptr))
     {
       /* read User preferences */
-      res = ufopen (ptr, TEXT("r"));
+      res = fopen (ptr, "r");
       if (res != NULL)
 	{
 #ifdef _WINDOWS
@@ -169,7 +165,7 @@ Document            doc;
 	    fclose (res);
 	  else
 	    {
-	      buffer = TtaAllocString (buf.st_size + 1000);
+	      buffer = TtaGetMemory (buf.st_size + 1000);
 	      if (buffer == NULL)
 		fclose (res);
 	      else
@@ -193,7 +189,7 @@ Document            doc;
       /* parse the whole thing and free the buffer */
       if (buffer != NULL)
 	{
-	  ReadCSSRules (doc, css, buffer, FALSE);
+	  ReadCSSRules (doc, css, buffer, 0, FALSE);
 	  TtaFreeMemory (buffer);
 	}
     }
@@ -203,12 +199,7 @@ Document            doc;
   AttrMediaChanged: the user has created removed or modified a Media
   attribute
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                AttrMediaChanged (NotifyAttribute * event)
-#else
-void                AttrMediaChanged (event)
-NotifyAttribute    *event;
-#endif
+void                AttrMediaChanged (NotifyAttribute *event)
 {
    ElementType         elType;
    Element             el;
@@ -218,9 +209,9 @@ NotifyAttribute    *event;
    CSSInfoPtr          css;
    CSSmedia            media;
    DisplayMode         dispMode;
-   CHAR_T              completeURL[MAX_LENGTH];
-   CHAR_T              tempname[MAX_LENGTH];
-   STRING              name2;
+   char                completeURL[MAX_LENGTH];
+   char                tempname[MAX_LENGTH];
+   char               *name2;
    int                 length;
 
    el = event->element;
@@ -234,13 +225,13 @@ NotifyAttribute    *event;
    elType = TtaGetElementType (el);
    /* get the new media value */
    length = TtaGetTextAttributeLength (attr);
-   name2 = TtaAllocString (length + 1);
+   name2 = TtaGetMemory (length + 1);
    TtaGiveTextAttributeValue (attr, name2, &length);
-   if (!ustrcasecmp (name2, TEXT ("screen")))
+   if (!strcasecmp (name2, "screen"))
      media = CSS_SCREEN;
-   else if (!ustrcasecmp (name2, TEXT ("print")))
+   else if (!strcasecmp (name2, "print"))
      media = CSS_PRINT;
-   else if (!ustrcasecmp (name2, TEXT ("all")))
+   else if (!strcasecmp (name2, "all"))
      media = CSS_ALL;
    else
      media = CSS_OTHER;
@@ -252,7 +243,7 @@ NotifyAttribute    *event;
    if (attr != NULL)
      {
        length = TtaGetTextAttributeLength (attr);
-       name2 = TtaAllocString (length + 1);
+       name2 = TtaGetMemory (length + 1);
        TtaGiveTextAttributeValue (attr, name2, &length);
        /* load the stylesheet file found here ! */
        NormalizeURL (name2, doc, completeURL, tempname, NULL);
@@ -290,20 +281,14 @@ NotifyAttribute    *event;
   - the the Document style sheet
   The returned string should be freed by the caller.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-STRING              CssToPrint (Document doc, STRING printdir)
-#else
-STRING              CssToPrint (doc, temdir)
-Document            doc;
-STRING              printdir;
-#endif
+char *CssToPrint (Document doc, char *printdir)
 {
   Element             el, head;
   ElementType         elType;
-  FILE*               file;
+  FILE               *file;
   CSSInfoPtr          css;
-  STRING              ptr, text;
-  CHAR_T              tempfile[MAX_LENGTH];
+  char               *ptr, *text, *name;
+  char                tempfile[MAX_LENGTH];
   int                 length, i;
 
   css = CSSList;
@@ -315,17 +300,19 @@ STRING              printdir;
       while (css != NULL)
 	{
 	  if (css->enabled[doc])
+	    {
 	    if ( css->category == CSS_DOCUMENT_STYLE)
 	      /* there is an internal style in the document */
-	      length += ustrlen (printdir) + 5;
+	      length += strlen (printdir) + 5;
 	    else
 	      /* that external or user style sheet concerns the document */
-	      length += ustrlen (css->localName) + 1;
+	      length += strlen (css->localName) + 1;
+	    }
 	  css = css->NextCSS;
 	}
       if (length)
 	{
-	  ptr = TtaAllocString (length + 1);
+	  ptr = TtaGetMemory (length + 1);
 	  length = 0;
 
 	  /* Add first the User style sheet */
@@ -336,8 +323,8 @@ STRING              printdir;
 		  css->category == CSS_USER_STYLE)
 		{
 		  /* add that file name to the list */
-		  ustrcpy (&ptr[length], css->localName);
-		  length += ustrlen (css->localName);
+		  strcpy (&ptr[length], css->localName);
+		  length += strlen (css->localName);
 		  ptr[length++] = SPACE;
 		  css = NULL;
 		}
@@ -353,8 +340,8 @@ STRING              printdir;
 		  css->category == CSS_EXTERNAL_STYLE)
 		{
 		  /* add that file name to the list */
-		  ustrcpy (&ptr[length], css->localName);
-		  length += ustrlen (css->localName);
+		  strcpy (&ptr[length], css->localName);
+		  length += strlen (css->localName);
 		  ptr[length++] = SPACE;
 		}
 	      css = css->NextCSS;
@@ -363,10 +350,26 @@ STRING              printdir;
 	  /* Then look for style elements within the document */
 	  el = TtaGetMainRoot (doc);
 	  elType = TtaGetElementType (el);
-	  elType.ElTypeNum = HTML_EL_HEAD;
-	  head = TtaSearchTypedElement (elType, SearchForward, el);
-	  elType.ElTypeNum = HTML_EL_STYLE_;
-	  el = head;
+	  name = TtaGetSSchemaName (elType.ElSSchema);
+	  if (!strcmp (name, "HTML"))
+	    {
+	      elType.ElTypeNum = HTML_EL_HEAD;
+	      head = TtaSearchTypedElement (elType, SearchForward, el);
+	      elType.ElTypeNum = HTML_EL_STYLE_;
+	      el = head;
+	    }
+#ifdef _SVG
+	  else if (!strcmp (name, "SVG"))
+	    {
+	    elType.ElTypeNum = SVG_EL_style__;
+	    head = el;
+	    }
+#endif /* _SVG */
+	  else
+	    {
+	      el = NULL;
+	      head = NULL;
+	    }
 	  while (el != NULL)
 	    {
 	      el = TtaSearchTypedElementInTree (elType, SearchForward, head, el);
@@ -375,16 +378,16 @@ STRING              printdir;
 		  if (!file)
 		    {
 		      /* build the temporary file name */
-		      i = ustrlen (printdir);
-		      ustrcpy (tempfile, printdir);
+		      i = strlen (printdir);
+		      strcpy (tempfile, printdir);
 		      tempfile[i++] = DIR_SEP;
-		      ustrcpy (&tempfile[i], TEXT("css"));
-		      file = ufopen (tempfile, TEXT("w"));
+		      strcpy (&tempfile[i], "css");
+		      file = fopen (tempfile, "w");
 		      if (file)
 			{
 			  /* add that file name to the list */
-			  ustrcpy (&ptr[length], tempfile);
-			  length += ustrlen (tempfile);
+			  strcpy (&ptr[length], tempfile);
+			  length += strlen (tempfile);
 			  ptr[length++] = SPACE;
 			}
 		    }
@@ -414,14 +417,7 @@ STRING              printdir;
 /*----------------------------------------------------------------------
    Callback procedure for dialogue events.                            
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         CallbackCSS (int ref, int typedata, STRING data)
-#else
-static void         CallbackCSS (ref, typedata, data)
-int                 ref;
-int                 typedata;
-STRING              data;
-#endif
+static void         CallbackCSS (int ref, int typedata, char *data)
 {
   CSSInfoPtr          css;
   PInfoPtr            pInfo;
@@ -440,21 +436,35 @@ STRING              data;
 	    {
 	    case 1:
 	      /* display the CSS file */
-	      GetHTMLDocument (CSSpath, NULL, 0, 0, CE_ABSOLUTE, FALSE, NULL, NULL);
+	      GetHTMLDocument (CSSpath, NULL, 0, 0, CE_CSS, FALSE,
+			       NULL, NULL);
 	      break;
 	    case 2:
 	      /* disable the CSS file, but not remove */
-	      RemoveStyleSheet (CSSpath, CSSdocument, TRUE, FALSE);
+	      if (!strcmp (CSSpath, TtaGetMessage (AMAYA, AM_LOCAL_CSS)))
+		RemoveStyleSheet (NULL, CSSdocument, TRUE, FALSE);
+	      else
+		RemoveStyleSheet (CSSpath, CSSdocument, TRUE, FALSE);
       	      break;
 	    case 3:
 	      /* enable the CSS file */
-	      css = SearchCSS (0, CSSpath);
-	      css ->enabled[CSSdocument] = TRUE;
-	      /* apply CSS rules */
-	      if (!ustrcmp (CSSpath, UserCSS))
-		LoadUserStyleSheet (CSSdocument);
+	      if (!strcmp (CSSpath, TtaGetMessage (AMAYA, AM_LOCAL_CSS)))
+		{
+		  css = SearchCSS (CSSdocument, NULL);
+		  css ->enabled[CSSdocument] = TRUE;
+		  EnableStyleElement (CSSdocument);
+		}
 	      else
-		LoadStyleSheet (CSSpath, CSSdocument, NULL, NULL, css->media[CSSdocument]);
+		{
+		  css = SearchCSS (0, CSSpath);
+		  css ->enabled[CSSdocument] = TRUE;
+		  /* apply CSS rules */
+		  if (UserCSS && !strcmp (CSSpath, UserCSS))
+		    LoadUserStyleSheet (CSSdocument);
+		  else
+		    LoadStyleSheet (CSSpath, CSSdocument, NULL, NULL,
+				    css->media[CSSdocument]);
+		}
       	      break;
 	    case 4:
 	      /* remove the link to this file */
@@ -462,10 +472,11 @@ STRING              data;
 	      found = FALSE;
 	      while (css != NULL && !found)
 		{
-		  if (css->category != CSS_DOCUMENT_STYLE &&
-		      css->documents[CSSdocument] &&
-		      ((css->url && !ustrcmp (CSSpath, css->url)) ||
-		       (css->localName && !ustrcmp (CSSpath, css->localName))))
+		  if (css->category == CSS_DOCUMENT_STYLE)
+		    DeleteStyleElement (CSSdocument);
+		  else if (css->documents[CSSdocument] &&
+			   ((css->url && !strcmp (CSSpath, css->url)) ||
+			    (css->localName && !strcmp (CSSpath, css->localName))))
 		    {
 		      /* we found out the CSS */
 		      found = TRUE;
@@ -498,9 +509,9 @@ STRING              data;
     case CSSSelect:
       if (CSSpath != NULL)
 	TtaFreeMemory (CSSpath);
-      length = ustrlen (data);
-      CSSpath = TtaAllocString (length + 1);
-      ustrcpy (CSSpath, data);      
+      length = strlen (data);
+      CSSpath = TtaGetMemory (length + 1);
+      strcpy (CSSpath, data);      
       break;
     default:
       break;
@@ -510,11 +521,7 @@ STRING              data;
 /*----------------------------------------------------------------------
    InitCSS                                                         
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                InitCSS (void)
-#else
-void                InitCSS ()
-#endif
 {
    /* initialize the dialogs */
    BaseCSS = TtaSetCallback (CallbackCSS, MAX_CSS_REF);
@@ -524,17 +531,11 @@ void                InitCSS ()
 /*----------------------------------------------------------------------
    InitCSSDialog list downloaded CSS files
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         InitCSSDialog (Document doc, STRING s)
-#else
-static void         InitCSSDialog (doc, s)
-Document            doc;
-STRING              s;
-#endif
+static void         InitCSSDialog (Document doc, char *s)
 {
   CSSInfoPtr          css;
-  CHAR_T              buf[400];
-  STRING              ptr;
+  char                buf[400];
+  char               *ptr;
   int                 i, select;
   int                 len, nb;
   int                 index, size;  
@@ -545,37 +546,38 @@ STRING              s;
   index = 0;
   nb = 0;
   size = 400;
-#  ifndef _WINDOWS
+#ifndef _WINDOWS
   /* create the form */
-  TtaNewSheet (BaseCSS + CSSForm, TtaGetViewFrame (doc, 1),
-	       s, 1,
+  TtaNewSheet (BaseCSS + CSSForm, TtaGetViewFrame (doc, 1), s, 1,
 	       TtaGetMessage(LIB, TMSG_LIB_CONFIRM), TRUE, 1, 'L', D_DONE);
-#  endif /* !_WINDOWS */
+#endif /* !_WINDOWS */
   select = -1;
   i = 0;
   while (css != NULL)
     {
-      if (css->category != CSS_DOCUMENT_STYLE &&
-	  css->documents[doc] &&
-	  /* it's impossible to remove the User style sheet */
-	  (CSScase < 4 || css->category == CSS_EXTERNAL_STYLE))
+      if (css->documents[doc] &&
+	       /* it's impossible to remove the User style sheet */
+	       (CSScase < 4 || css->category == CSS_EXTERNAL_STYLE))
 	{
 	  if ((CSScase == 3 && !css->enabled[doc]) ||
 	      (CSScase == 2 && css->enabled[doc]) ||
-	      CSScase == 1 || CSScase == 4)
+	      (CSScase == 1 && css->category != CSS_DOCUMENT_STYLE) ||
+	      CSScase == 4)
 	    {
 	      /* filter enabled and disabled entries */
 	      /* build the CSS list */
-	      if (css->url == NULL)
+	      if (css->category == CSS_DOCUMENT_STYLE)
+		ptr = TtaGetMessage (AMAYA, AM_LOCAL_CSS);
+	      else if (css->url == NULL)
 		ptr = css->localName;
 	      else
 		ptr = css->url;
 
-	      len = ustrlen (ptr);
+	      len = strlen (ptr);
 	      len++;
 	      if (size < len)
 		break;
-	      ustrcpy (&buf[index], ptr);
+	      strcpy (&buf[index], ptr);
 	      index += len;
 	      nb++;
 	      size -= len;
@@ -584,18 +586,12 @@ STRING              s;
 		{
 		  if (CSSpath != NULL)
 		    TtaFreeMemory (CSSpath);
-		  if (css->url)
-		    {
-		      len = ustrlen (css->url);
-		      CSSpath = TtaAllocString (len + 1);
-		      ustrcpy (CSSpath, css->url);
-		    }
+		  if (css->category == CSS_DOCUMENT_STYLE)
+		    CSSpath = TtaStrdup (TtaGetMessage (AMAYA, AM_LOCAL_CSS));
+		  else if (css->url)
+		    CSSpath = TtaStrdup (css->url);
 		  else
-		    {
-		      len = ustrlen (css->localName);
-		      CSSpath = TtaAllocString (len + 1);
-		      ustrcpy (CSSpath, css->localName);
-		    }
+		    CSSpath = TtaStrdup (css->localName);
 		  select = i;
 		}
 	      i++;
@@ -606,12 +602,19 @@ STRING              s;
 
   /* display the form */
 #  ifdef _WINDOWS
-  CreateCSSDlgWindow (TtaGetViewFrame (doc, 1), nb, buf, s, TtaGetMessage (AMAYA, AM_NO_CCS_FILE));
+  CreateCSSDlgWindow (TtaGetViewFrame (doc, 1), nb, buf, s,
+		      TtaGetMessage (AMAYA, AM_NO_CCS_FILE));
 #  else  /* !_WINDOWS */
   if (nb > 0)
-    TtaNewSelector (BaseCSS + CSSSelect, BaseCSS + CSSForm,
-		    TtaGetMessage (AMAYA, AM_CSS_FILE),
-		    nb, buf, 5, NULL, FALSE, TRUE);
+    {
+      if (nb >= 10)
+	i = 10;
+      else
+	i = nb;
+      TtaNewSizedSelector (BaseCSS + CSSSelect, BaseCSS + CSSForm,
+			   TtaGetMessage (AMAYA, AM_CSS_FILE),
+			   nb, buf, 200, i, NULL, FALSE, TRUE);
+    }
   else
     TtaNewLabel (BaseCSS + CSSSelect, BaseCSS + CSSForm,
 		 TtaGetMessage (AMAYA, AM_NO_CCS_FILE));
@@ -624,13 +627,7 @@ STRING              s;
 /*----------------------------------------------------------------------
    LinkCSS
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                LinkCSS (Document doc, View view)
-#else
-void                LinkCSS (doc, view)
-Document            doc;
-View                view;
-#endif
 {
   /* add a new link to a CSS file */
   LinkAsCSS = TRUE;
@@ -641,13 +638,7 @@ View                view;
 /*----------------------------------------------------------------------
    OpenCSS lists downloaded CSS files
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                OpenCSS (Document doc, View view)
-#else
-void                OpenCSS (doc, view)
-Document            doc;
-View                view;
-#endif
 {
   CSScase = 1;
   InitCSSDialog (doc, TtaGetMessage (1, BOpenCSS));
@@ -656,13 +647,7 @@ View                view;
 /*----------------------------------------------------------------------
    DisableCSS list downloaded CSS files
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                DisableCSS (Document doc, View view)
-#else
-void                DisableCSS (doc, view)
-Document            doc;
-View                view;
-#endif
 {
   CSScase = 2;
   InitCSSDialog (doc, TtaGetMessage (1, BDisableCSS));
@@ -671,13 +656,7 @@ View                view;
 /*----------------------------------------------------------------------
   EnableCSS list downloaded CSS files
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                EnableCSS (Document doc, View view)
-#else
-void                EnableCSS (doc, view)
-Document            doc;
-View                view;
-#endif
 {
   CSScase = 3;
   InitCSSDialog (doc, TtaGetMessage (1, BEnableCSS));
@@ -686,13 +665,7 @@ View                view;
 /*----------------------------------------------------------------------
    RemoveCSS lists downloaded CSS files
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                RemoveCSS (Document doc, View view)
-#else
-void                RemoveCSS (doc, view)
-Document            doc;
-View                view;
-#endif
 {
   CSScase = 4;
   InitCSSDialog (doc, TtaGetMessage (1, BRemoveCSS));
