@@ -18,18 +18,30 @@
  * NOTE: the code assumes libwww's RDF parser.
  *
  * Author: Ralph R. Swick (W3C/MIT)
- * $Revision: 1.18 $
+ * $Revision: 1.25 $
  *
  */
 
+/* system includes */
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "xmlparse.h"
+
+/* annotlib includes */
 #include "annotlib.h"
-#include "AHTURLTools_f.h"
+#include "ANNOTschemas_f.h"
+#include "ANNOTtools_f.h"
+#include "ANNOTevent_f.h"
+
+/* libwww includes */
+#include "xmlparse.h"
 #include "HTRDF.h"
 
+/* amaya includes */
+#include "AHTURLTools_f.h"
+#include "init_f.h"
+#include "query_f.h"
+
 /********************** static variables ***********************/
 
 /* 
@@ -43,14 +55,21 @@ static RDFPropertyP labelP = NULL;
 /********************** global variables ***********************/
 
 List *annot_schema_list = NULL;  /* a list of schemas */
-CHAR_T *ANNOT_NS = NULL;	/* the Annotation namespace name to use */
-CHAR_T *ANNOTATION_CLASSNAME = NULL;
+char *ANNOT_NS = NULL;	/* the Annotation namespace name to use */
+char *ANNOTATION_CLASSNAME = NULL;
 RDFPropertyP PROP_name = NULL;
 RDFPropertyP PROP_firstName = NULL;
 RDFPropertyP PROP_Email = NULL;
+RDFPropertyP PROP_usesIcon = NULL;
 RDFClassP ANNOTATION_CLASS;
 RDFClassP DEFAULT_ANNOTATION_TYPE;
 
+#ifdef ANNOT_ON_ANNOT
+RDFClassP THREAD_REPLY_CLASS;
+RDFClassP DEFAULT_REPLY_TYPE;
+#endif /* ANNOT_ON_ANNOT */
+
+
 typedef struct _ReadCallbackContext
 {
   char filename[MAX_LENGTH];
@@ -69,7 +88,7 @@ static RDFResourceP _ListSearchResource( List* list, char* name)
     {
       resource = (RDFResourceP) item->object;
       if (resource && resource->name 
-	  && !ustrcmp (resource->name, name))
+	  && !strcmp (resource->name, name))
 	{
 	  found = TRUE;
 	  break;
@@ -187,8 +206,8 @@ static void triple_handler (HTRDF * rdfp, HTTriple * triple, void * context)
   -----------------------------------------------------------------------*/
 #ifdef __STDC__
 static void ReadSchema_callback (Document doc, int status, 
-				 CHAR_T *urlName,
-				 CHAR_T *outputfile, 
+				 char *urlName,
+				 char *outputfile, 
 				 AHTHeaders *http_headers,
 				 void * context)
 #else  /* __STDC__ */
@@ -197,8 +216,8 @@ static void ReadSchema_callback (doc, status, urlName,
 				 context)
 Document doc;
 int status;
-CHAR_T *urlName;
-CHAR_T *outputfile;
+char *urlName;
+char *outputfile;
 AHTHeaders *http_headers;
 void *context;
 
@@ -248,7 +267,8 @@ RDFResourceP ANNOT_FindRDFResource( listP, name, create )
   resource = _ListSearchResource (*listP, name);
   if ((!resource || !resource->name) && create)
     {
-      resource = TtaGetMemory (sizeof(RDFResource));
+      if (!resource)
+        resource = TtaGetMemory (sizeof(RDFResource));
 
       resource->name = TtaStrdup (name);
       resource->statements = NULL;
@@ -388,7 +408,7 @@ void SCHEMA_ReadSchema (doc, namespace_URI)
 			  (void *) ReadSchema_callback,
 			  (void *) ctx,
 			  NO,
-			  TEXT("application/xml"));
+			  "application/xml");
     }
 
   if (res != HT_OK)
@@ -434,8 +454,8 @@ static void SetAnnotNS ()
   ANNOTATION_CLASSNAME = TtaGetMemory (strlen(ns_name)
 				       + strlen(ANNOT_LOCAL_NAME)
 				       + 1);
-  ustrcpy (ANNOTATION_CLASSNAME, ns_name);
-  ustrcat (ANNOTATION_CLASSNAME, ANNOT_LOCAL_NAME);
+  strcpy (ANNOTATION_CLASSNAME, ns_name);
+  strcat (ANNOTATION_CLASSNAME, ANNOT_LOCAL_NAME);
 
   ANNOTATION_CLASS = ANNOT_FindRDFResource (&annot_schema_list,
 					    ANNOTATION_CLASSNAME,
@@ -463,11 +483,11 @@ void SCHEMA_InitSchemas (doc)
      Document doc;
 #endif /* __STDC__ */
 {
-  CHAR_T* thotdir;
-  CHAR_T *app_home;
+  char* thotdir;
+  char *app_home;
   FILE *fp;
   int len;
-  CHAR_T *buffer;
+  char *buffer;
 
   thotdir = TtaGetEnvString ("THOTDIR");
   app_home = TtaGetEnvString ("APP_HOME");
@@ -489,11 +509,11 @@ void SCHEMA_InitSchemas (doc)
   len = strlen(thotdir) + strlen(app_home) + MAX_LENGTH + 32;
 
   buffer = TtaGetMemory(len);
-  usprintf (buffer, TEXT("%s%cannot.schemas"), app_home, DIR_SEP);
+  sprintf (buffer, "%s%cannot.schemas", app_home, DIR_SEP);
 
   if (!TtaFileExist (buffer))
     {
-      usprintf (buffer, TEXT("%s%cconfig%cannot.schemas"),
+      sprintf (buffer, "%s%cconfig%cannot.schemas",
 		thotdir, DIR_SEP, DIR_SEP);
 
       if (!TtaFileExist (buffer))
@@ -511,6 +531,7 @@ void SCHEMA_InitSchemas (doc)
     {
       /* RRS @@ installation error */
       SetAnnotNS (FALLBACK_ANNOTATION_NS);
+      TtaFreeMemory (buffer);
       return;
     }
 
@@ -563,6 +584,7 @@ void SCHEMA_InitSchemas (doc)
 	       so copy the filename elsewhere before concatenating */
 	    {
 	      char *temp = TtaGetMemory(len);
+
 	      strcpy (temp, fname); /* copy */
 	      strcpy (buffer, thotdir);
 	      strcat (buffer, temp+8);
@@ -583,6 +605,7 @@ void SCHEMA_InitSchemas (doc)
 		 so copy the filename elsewhere before concatenating */
 	      {
 		char *temp = TtaGetMemory(len);
+
 		strcpy (temp, fname); /* copy */
 		strcpy (buffer, app_home);
 		strcat (buffer, temp+9);
@@ -615,7 +638,7 @@ void SCHEMA_InitSchemas (doc)
   /* @@ RRS: ANNOT_DEFAULT_TYPE should be accessible from the config menu */
   buffer = TtaGetEnvString ("ANNOT_DEFAULT_TYPE");
   if (!buffer)
-    buffer = TEXT("Comment");	/* fallback default type */
+    buffer = "Comment";	/* fallback default type */
 
   /* two options; user can specify a full property URI or just the localname */
   if (IsW3Path (buffer)) /* full URI */
@@ -644,6 +667,44 @@ void SCHEMA_InitSchemas (doc)
 	    }
 	}
     }
+#ifdef ANNOT_ON_ANNOT
+  THREAD_REPLY_CLASS = ANNOT_FindRDFResource (&annot_schema_list,
+					      THREAD_NS THREAD_REPLY_LOCAL_NAME,
+					      TRUE);
+  DEFAULT_REPLY_TYPE = THREAD_REPLY_CLASS;
+  /* @@ RRS: REPLY_DEFAULT_TYPE should be accessible from the config menu */
+  buffer = TtaGetEnvString ("REPLY_DEFAULT_TYPE");
+  if (!buffer)
+    buffer = "Comment";	/* fallback default type */
+
+  /* two options; user can specify a full property URI or just the localname */
+  if (IsW3Path (buffer)) /* full URI */
+    DEFAULT_REPLY_TYPE = ANNOT_FindRDFResource (&annot_schema_list,
+						buffer,
+						TRUE);
+  else /* localname only */
+    { /* Search the subtypes of THREAD_REPLY_CLASS for one whose name matches */
+      RDFClassP annotType = THREAD_REPLY_CLASS;
+      if (annotType && annotType->class)
+	{
+	  int len = strlen (buffer);
+	  List *item = annotType->class->subClasses;
+	  for (; item; item=item->next)
+	    {
+	      RDFClassP annotType = (RDFClassP)item->object;
+	      int p = strlen (annotType->name) - len;
+
+	      /* @@ RRS: should check the entire localname, not just the tail.
+		 Use rdfs:isDefinedBy to split out the namespace name. */
+	      if (!strncmp (buffer, &annotType->name[p], len))
+		{
+		  DEFAULT_REPLY_TYPE = annotType;
+		  break;
+		}
+	    }
+	}
+    }
+#endif /* ANNOT_ON_ANNOT */
 }
 
 
@@ -690,8 +751,9 @@ static ThotBool SCHEMA_FreeRDFResource( void *item )
     {
       List_delAll (&r->class->instances, NULL);
       List_delAll (&r->class->subClasses, NULL);
-      TtaFreeMemory ((CHAR_T *)r->class);
+      TtaFreeMemory ((char *)r->class);
     }
+  TtaFreeMemory (r);
   return TRUE;
 }
 
@@ -715,8 +777,13 @@ void SCHEMA_FreeAnnotSchema()
   PROP_name = NULL;
   PROP_firstName = NULL;
   PROP_Email = NULL;
+  PROP_usesIcon = NULL;
   ANNOTATION_CLASS = NULL;
   DEFAULT_ANNOTATION_TYPE = NULL;
+#ifdef ANNOT_ON_ANNOT
+  THREAD_REPLY_CLASS = NULL;
+  DEFAULT_REPLY_TYPE = NULL;
+#endif /* ANNOT_ON_ANNOT */
   FreeAnnotNS();
 }
 
