@@ -56,7 +56,7 @@ void                WriteName (Name n)
 
    i = 0;
    do
-      TtaWriteWideChar (outfile, n[i++], ISO_8859_1);
+      TtaWriteByte (outfile, n[i++]);
    while (n[i - 1] != '\0');
 }
 
@@ -581,7 +581,7 @@ void WriteBlocks (PtrTRuleBlock pBlock, PtrSSchema pSS)
 			 break;
 		      case TcondAttr:
 			 WriteShort (pCond->TcAttr);
-			 switch (pSS->SsAttribute[pCond->TcAttr - 1].AttrType)
+			 switch (pSS->SsAttribute->TtAttr[pCond->TcAttr - 1]->AttrType)
 			       {
 				  case AtNumAttr:
 				     WriteSignedShort (pCond->TcLowerBound);
@@ -638,13 +638,13 @@ void WriteBlocks (PtrTRuleBlock pBlock, PtrSSchema pSS)
   ----------------------------------------------------------------------*/
 void WriteTRulesAttr (int att, PtrSSchema pSS, PtrTSchema pTSch)
 {
-   AttributeTransl    *pAttrT;
+   PtrAttributeTransl  pAttrT;
    TranslNumAttrCase  *pCase;
    int                 i;
 
-   pAttrT = &pTSch->TsAttrTRule[att - 1];
+   pAttrT = pTSch->TsAttrTRule->TsAttrTransl[att - 1];
    WriteShort (pAttrT->AtrElemType);
-   switch (pSS->SsAttribute[att - 1].AttrType)
+   switch (pSS->SsAttribute->TtAttr[att - 1]->AttrType)
 	 {
 	    case AtNumAttr:
 	       WriteShort (pAttrT->AtrNCases);
@@ -664,7 +664,7 @@ void WriteTRulesAttr (int att, PtrSSchema pSS, PtrTSchema pTSch)
 	       WriteBlocks (pAttrT->AtrRefTRuleBlock, pSS);
 	       break;
 	    case AtEnumAttr:
-	       for (i = 0; i <= pSS->SsAttribute[att - 1].AttrNEnumValues; i++)
+	       for (i = 0; i <= pSS->SsAttribute->TtAttr[att - 1]->AttrNEnumValues; i++)
 		  WriteBlocks (pAttrT->AtrEnuTRuleBlock[i], pSS);
 	       break;
 	    default:
@@ -719,7 +719,7 @@ ThotBool WriteTranslationSchema (Name fileName, PtrTSchema pTSch, PtrSSchema pSS
    TCounter           *pCntr;
    TranslVariable     *pVar;
    TranslVarItem      *pVarItem;
-   AttributeTransl    *pAttrTr;
+   PtrAttributeTransl  pAttrTr;
    AlphabetTransl     *pAlphTr;
    StringTransl       *pStrnTr;
    PRuleTransl        *pPruleTr;
@@ -777,33 +777,32 @@ ThotBool WriteTranslationSchema (Name fileName, PtrTSchema pTSch, PtrSSchema pSS
      }
    WriteShort (pTSch->TsPictureBuffer);
    for (i = 0; i < pSS->SsNRules; i++)
-      WriteBlockPtr (pTSch->TsElemTRule[i]);
+      WriteBlockPtr (pTSch->TsElemTRule->TsElemTransl[i]);
    for (i = 0; i < pSS->SsNRules; i++)
-      WriteBoolean (pTSch->TsInheritAttr[i]);
+      WriteBoolean (pTSch->TsInheritAttr->Bln[i]);
    for (i = 0; i < pSS->SsNAttributes; i++)
      {
-	pAttrTr = &pTSch->TsAttrTRule[i];
-	switch (pSS->SsAttribute[i].AttrType)
-	      {
-		 case AtNumAttr:
-		    WriteShort (pAttrTr->AtrNCases);
-		    for (j = 0; j < pAttrTr->AtrNCases; j++)
-		       WriteBlockPtr (pAttrTr->AtrCase[j].TaTRuleBlock);
-		    break;
-		 case AtTextAttr:
-		    WriteBlockPtr (pAttrTr->AtrTxtTRuleBlock);
-		    break;
-		 case AtReferenceAttr:
-		    WriteBlockPtr (pAttrTr->AtrRefTRuleBlock);
-		    break;
-		 case AtEnumAttr:
-		    for (j = 0; j <= pSS->SsAttribute[i].AttrNEnumValues; j++)
-		       WriteBlockPtr (pAttrTr->AtrEnuTRuleBlock[j]);
-		    break;
-		 default:
-		    break;
-	      }
-
+       pAttrTr = pTSch->TsAttrTRule->TsAttrTransl[i];
+       switch (pSS->SsAttribute->TtAttr[i]->AttrType)
+	 {
+	 case AtNumAttr:
+	   WriteShort (pAttrTr->AtrNCases);
+	   for (j = 0; j < pAttrTr->AtrNCases; j++)
+	     WriteBlockPtr (pAttrTr->AtrCase[j].TaTRuleBlock);
+	   break;
+	 case AtTextAttr:
+	   WriteBlockPtr (pAttrTr->AtrTxtTRuleBlock);
+	   break;
+	 case AtReferenceAttr:
+	   WriteBlockPtr (pAttrTr->AtrRefTRuleBlock);
+	   break;
+	 case AtEnumAttr:
+	   for (j = 0; j <= pSS->SsAttribute->TtAttr[i]->AttrNEnumValues; j++)
+	     WriteBlockPtr (pAttrTr->AtrEnuTRuleBlock[j]);
+	   break;
+	 default:
+	   break;
+	 }
      }
    for (i = 0; i < MAX_TRANSL_PRULE; i++)
      {
@@ -843,22 +842,22 @@ ThotBool WriteTranslationSchema (Name fileName, PtrTSchema pTSch, PtrSSchema pSS
 	pStrnTr = &pTSch->TsCharTransl[i];
 	j = 0;
 	do
-	   TtaWriteWideChar (outfile, pStrnTr->StSource[j++], ISO_8859_1);
+	   TtaWriteByte (outfile, pStrnTr->StSource[j++]);
 	while (pStrnTr->StSource[j - 1] != '\0');
 	j = 0;
 	do
-	   TtaWriteWideChar (outfile, pStrnTr->StTarget[j++], ISO_8859_1);
+	   TtaWriteByte (outfile, pStrnTr->StTarget[j++]);
 	while (pStrnTr->StTarget[j - 1] != '\0');
      }
    for (i = 0; i < pTSch->TsNConstants; i++)
      {
 	j = pTSch->TsConstBegin[i] - 1;
 	do
-	   TtaWriteWideChar (outfile, pTSch->TsConstant[j++], ISO_8859_1);
+	   TtaWriteByte (outfile, pTSch->TsConstant[j++]);
 	while (pTSch->TsConstant[j - 1] != '\0');
      }
    for (i = 0; i < pSS->SsNRules; i++)
-      WriteBlocks (pTSch->TsElemTRule[i], pSS);
+      WriteBlocks (pTSch->TsElemTRule->TsElemTransl[i], pSS);
    for (i = 0; i < pSS->SsNAttributes; i++)
       WriteTRulesAttr (i + 1, pSS, pTSch);
    for (i = 0; i < MAX_TRANSL_PRULE; i++)
