@@ -24,7 +24,6 @@
 #include "message.h"
 #include "dictionary.h"
 #include "fileaccess.h"
-#include "thotdir.h"
 
 #define MAX_DICTS        2	/* Maximum number of dictionaries related to a given language */
 #define MAXLIGNE        80	/* Length of a line in the dictionary                         */
@@ -82,7 +81,7 @@ static void           LoadAlphabet ()
 /*----------------------------------------------------------------------
   Resolves the common characters for two consecutive words 
   ----------------------------------------------------------------------*/
-void                TreateDictionary (PtrDict dict)
+void TreateDictionary (PtrDict dict)
 {
    int                 word, i;
    char                lastWord[MAX_WORD_LEN];
@@ -126,7 +125,7 @@ void                TreateDictionary (PtrDict dict)
    ReleaseDictionary: Releases dictionaries which descriptor is    
    referenced by pDictionary.                   
   ----------------------------------------------------------------------*/
-static void         ReleaseDictionary (PtrDict *pDictionary)
+static void ReleaseDictionary (PtrDict *pDictionary)
 {
    int                 d;
    PtrDict             pdict;
@@ -267,18 +266,10 @@ static void ReadDictionary (FILE *dictFile, PtrDict dict)
   if (!dict->DictLoaded)
     {
       /* Loading ... */
-      i = 0;
-      while (i < dict->DictNbChars)
-	{
-	  TtaReadByte (dictFile, &(dict->DictString[i]));
-	  i++;
-	}
-      i = 0;
-      while (i < dict->DictNbWords)
-	{
-	  TtaReadByte (dictFile, &(dict->DictCommon[i]));
-	  i++;
-	}
+      for (i = 0; i < dict->DictNbChars; i++)
+	TtaReadByte (dictFile, &(dict->DictString[i]));
+      for (i = 0; i < dict->DictNbWords; i++)
+	TtaReadByte (dictFile, &(dict->DictCommon[i]));
       for (i = 0; i < dict->DictNbWords; i++)
 	TtaReadInteger (dictFile, &dict->DictWords[i]);
       for (i = 0; i < MAX_WORD_LEN; i++)
@@ -401,7 +392,7 @@ static void PrepareDictionary (PtrDict *pDictionary, char *dictName,
   else
     {
       /* READONLY dictionary (generally pre-treated) */
-      if (treated == TRUE)
+      if (treated)
 	dictFile = TtaReadOpen (tempbuffer);
       else
 	dictFile = fopen (tempbuffer, "r");
@@ -430,13 +421,13 @@ static void PrepareDictionary (PtrDict *pDictionary, char *dictName,
   pdict->DictReadOnly = readonly;
   
   /* calculation of the memory size needed by the dictionary */
-  if (new == FALSE)
+  if (!new)
     {
       if (treated)
 	/* dictionary already treated */
 	{
 	  ret = TtaReadInteger (dictFile, &i);
-	  if (ret == FALSE)
+	  if (!ret)
 	    {
 	      TtaReadClose (dictFile);
 	      /* no memory */
@@ -494,7 +485,7 @@ static void PrepareDictionary (PtrDict *pDictionary, char *dictName,
       ReleaseDictionary (pDictionary);
       *pDictionary = NULL;
     }
-  else if (treated == TRUE)
+  else if (treated)
     /* Read the pre-treated file */
     ReadDictionary (dictFile, pdict);
   else if (!pdict->DictLoaded)
@@ -638,7 +629,7 @@ ThotBool ReloadDictionary (PtrDict *pDictionary)
 /*----------------------------------------------------------------------
    Dict_Init                                                       
   ----------------------------------------------------------------------*/
-void                Dict_Init ()
+void Dict_Init ()
 {
    int                 i;
 
