@@ -63,6 +63,7 @@ KEY;
 
 #ifdef _GTK
 #include "gtk-functions.h"
+#include "absboxes_f.h" 
 #else /* _GTK */
 #include "appli_f.h"
 #include "input_f.h"
@@ -538,14 +539,13 @@ void WIN_CharTranslation (HWND hWnd, int frame, UINT msg, WPARAM wParam,
    ThotInput (frame, &string[0], len, keyboard_mask, wParam);
 }
 #else /* _WINDOWS */
-
+#ifdef _GTK
 /*----------------------------------------------------------------------
-   CharTranslation
-   X-Window front-end to the character translation and handling.
-   Decodes the X-Window event  and calls the generic character
+   CharTranslationGTK
+   GTK front-end to the character translation and handling.
+   Decodes the GTK key press event  and calls the generic character
    handling function.
   ----------------------------------------------------------------------*/
-#ifdef _GTK
 gboolean CharTranslationGTK (GtkWidget *w, GdkEventKey* event, gpointer data)
 {
    int                 status;
@@ -553,63 +553,198 @@ gboolean CharTranslationGTK (GtkWidget *w, GdkEventKey* event, gpointer data)
    int                 frame;
    unsigned int        state, save;
    unsigned char       string[2];
-   ThotComposeStatus   ComS;
    KeySym              KS;
    GtkWidget          *drawing_area;
    GtkEntry           *textzone;
 
-  frame = (int) data;
+   frame = (int) data;
    if (frame > MAX_FRAME)
-      frame = 0;
-   
-   /*   printf("KEY event\n");*/
+     frame = 0;
    /* the drawing area is the main zone where keypress event must be active */
    drawing_area = FrameTable[frame].WdFrame;
-   textzone = FrameTable[frame].Text_Zone[1];
-
-
-   if (textzone)
-     {
-       /* if the mouse is into the text zone then event must be ignored */
-       if (w == textzone || gtk_object_get_data (GTK_OBJECT(textzone), "MouseIn"))
-	 {
-	   return FALSE;
-	 }
+   /* Focus is on all the drawing frame : 
+      Drawing area and his hiden text catcher (for multikey),
+      and the URLtext textzone, 
+      so we must now know where is the focus, 
+      to analyse the meaning of the keypress
+      and setting it on one of the  textfields*/
+   if (FrameTable[frame].Text_Zone[1])
+       {
+	   
+	 if (GTK_WIDGET_HAS_FOCUS (FrameTable[frame].Text_Zone[1]))
+	    { 
+		 /* We're in the url zone*/
+		 return FALSE;
+	    } 
+	 else
+	    { 
+		 /* We're in the drawing so get the hidden textfield adress*/		 
+		 textzone = gtk_object_get_data (GTK_OBJECT (drawing_area), "Text_catcher");
+		 gtk_widget_grab_focus (GTK_WIDGET(textzone));
+	     }
      }
-   /* force the focus into the drawing area */
-   gtk_widget_grab_focus (drawing_area);
 
    status = 0;
    /* control, alt and mouse status bits of the state are ignored */
    state = event->state & (GDK_SHIFT_MASK | GDK_LOCK_MASK | GDK_MOD3_MASK);
-   if (event->state == state)
-     {
-       strncpy (string, event->string, 2);
-       KS = event->keyval;
-     }
-   else
+
+   strncpy(string, event->string, 2);
+   KS = event->keyval;
+   if (event->state != state)
      {
        save = event->state;
        event->state = state;
        state = save;
-       strncpy (string, event->string, 2);
-       KS = event->keyval;
      }
-
    PicMask = 0;
    if (state & GDK_SHIFT_MASK)
       PicMask |= THOT_MOD_SHIFT;
    /*if (state & GDK_LOCK_MASK)
      PicMask |= THOT_MOD_SHIFT;*/
    if (state & GDK_CONTROL_MASK)
-      PicMask |= THOT_MOD_CTRL;
+       PicMask |= THOT_MOD_CTRL;
    if (state & GDK_MOD1_MASK || state & GDK_MOD4_MASK)
       PicMask |= THOT_MOD_ALT;
+   if (event->keyval == GDK_space)
+     event->length = 1;
    ThotInput (frame, &string[0], event->length, PicMask, KS);
    return FALSE;
 }
 
+/*----------------------------------------------------------------------
+   GtkLining
+   When user hold clicked a button or pressed a key
+   those functions are called by a timer each 100 ms
+   in order to repeat user action until he released the button
+   or move away from the widget.
+----------------------------------------------------------------------*/
+
+gboolean GtkLiningDown(gpointer data)
+{
+  int       frame;
+  Document  doc; 
+  int       view;
+  
+   frame = (int) data; 
+   FrameToView (frame, &doc, &view);
+   TtcLineDown (doc, view);
+   /* As this is a timeout function, return TRUE so that it
+     continues to get called */
+   return TRUE;
+}
+gboolean GtkLiningUp(gpointer data)
+{
+  int       frame;
+  Document  doc; 
+  int       view;
+  
+  frame = (int) data; 
+  FrameToView (frame, &doc, &view);
+  TtcLineUp (doc, view);
+  /* As this is a timeout function, return TRUE so that it
+     continues to get called */
+  return TRUE;
+}
+/*----------------------------------------------------------------------
+   KeyScrolledGTK
+   Capture click on the scrollbar in order to enable
+   Crtl + click event, that let user go on top or bottom of the doc
+   Click on button in order to move only for one line and without calling
+   recursivly the FrameVScrolled callback.   
+  ----------------------------------------------------------------------*/
+gboolean KeyScrolledGTK (GtkWidget *w, GdkEvent* event, gpointer data)
+{ 
+  int                 frame;
+  GdkEventKey         *eventkey;
+  GdkEventButton      *eventmouse;
+  Document            doc; 
+  int                 view;
+  int                 x,y;
+  int                 height;
+  static int          timer = None; 
+  
+  frame = (int) data; 
+  FrameToView (frame, &doc, &view);
+  gdk_window_get_position(w->parent->parent->parent->window, &x, &y);
+  if (timer != None)
+    {
+      gtk_timeout_remove (timer);
+      timer = None;
+    } 
+  if (event->type != GDK_LEAVE_NOTIFY)
+    gtk_widget_grab_focus (GTK_WIDGET(w));  
+  if (event->type == GDK_BUTTON_PRESS)
+    {
+      eventmouse = (GdkEventButton*) event;
+      if (eventmouse->button == 1) 
+	{
+	  /* 16 is the pixel size of the scrollbar buttons*/
+	  height = w->allocation.height - 16;
+	  /* 
+	     Gives the real Y 
+	     (eventmouse->y GTK gives bad number on the lower button)
+	     So We use the Window manager one and calculate absolute position...
+	  */
+	  y = eventmouse->y_root - y - w->allocation.y;
+	  if (eventmouse->state & GDK_CONTROL_MASK)
+	    {
+	      if (y > height)
+		JumpIntoView (frame, 100);			
+	      else if (y < 16)
+		JumpIntoView (frame, 0);
+	    }
+	  else if  (y > height){
+	    TtcLineDown (doc, view); 
+	    timer = gtk_timeout_add (100, GtkLiningDown, (gpointer) frame);
+	  }
+	  else if  (y < 16){
+	    TtcLineUp (doc, view);	    
+	    timer = gtk_timeout_add (100, GtkLiningUp, (gpointer) frame);
+	  }
+	  else
+	    return FALSE;
+	  /* this prevent GTK Callback to act !!*/
+	  gtk_signal_emit_stop_by_name (GTK_OBJECT(w), "button_press_event");
+	  return TRUE;
+	}
+		 
+    } 
+  /*
+    Code is here, but didn't manage to always catch those events..
+    But as CRTL + UP and CTRL + DOWN work like UP and DOWN should...
+    The problem is that Key event are catched before, by the Main Window 
+    In CharTranslation GTK... We need to redesign all Key catching if we 
+    wanna catch UP and DOWN... As we sadly cannot get mouse position in a key event..
+   */
+  else if (event->type == GDK_KEY_PRESS)
+    {
+      eventkey = (GdkEventKey*) event;
+      if (eventkey->keyval == GDK_Up) 
+	{ 
+	  TtcLineDown (doc, view); 
+	  timer = gtk_timeout_add (50, GtkLiningDown, (gpointer) frame);
+	  /* this prevent GTK Callback to act !!*/
+	  gtk_signal_emit_stop_by_name (GTK_OBJECT(w), "key_press_event");
+	  return TRUE;
+	}
+      else if (eventkey->keyval == GDK_Down)
+	{ 
+	  TtcLineDown (doc, view); 
+	  timer = gtk_timeout_add (50, GtkLiningDown, (gpointer) frame);
+	   /* this prevent GTK Callback to act !!*/
+	  gtk_signal_emit_stop_by_name (GTK_OBJECT(w), "key_press_event");
+	  return TRUE;
+	}
+    }
+  return FALSE;
+}
 #else /* _GTK */
+/*----------------------------------------------------------------------
+   CharTranslation
+   X-Window front-end to the character translation and handling.
+   Decodes the X-Window event  and calls the generic character
+   handling function.
+  ----------------------------------------------------------------------*/
 void CharTranslation (ThotKeyEvent *event)
 {
    KeySym              KS;
@@ -645,7 +780,7 @@ void CharTranslation (ThotKeyEvent *event)
 
    ThotInput (frame, &string[0], status, PicMask, KS);
 }
-#endif /* _GTK */
+#endif /* _MOTIF */
 #endif /* !_WINDOWS */
 
 /*----------------------------------------------------------------------
