@@ -1,19 +1,10 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
-/*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
 /*
  * Handle scrolling in document frames
  *
@@ -39,7 +30,7 @@
 #include "frame_f.h"
 #include "structselect_f.h"
 #include "textcommands_f.h"
-#include "windowdisplay_f.h"
+#include "xwindowdisplay_f.h"
 
 
 /*----------------------------------------------------------------------
@@ -52,15 +43,7 @@
    Le parametre selection indique s'il faut ge'rer la      
    selection (valeur 1) ou non (valeur 0).                 
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                VerticalScroll (int frame, int delta, int selection)
-#else  /* __STDC__ */
-void                VerticalScroll (frame, delta, selection)
-int                 frame;
-int                 delta;
-int                 selection;
-#endif /* __STDC__ */
-
+void VerticalScroll (int frame, int delta, int selection)
 {
    int                 y, height;
    int                 max, width;
@@ -84,24 +67,27 @@ int                 selection;
 	       {
 		  /* A priori pas de paves ajoutes */
 		  add = FALSE;
-		  /* Au plus, la limite du document + le debordement vertical */
+		  /* Au plus, la limite du document + le debordement vertical*/
 		  GetSizesFrame (frame, &lframe, &hframe);
 		  if (pAbb->AbTruncatedTail)
 		     max = delta;
 		  else
-		     max = srcbox->BxYOrg + srcbox->BxHeight - pFrame->FrYOrg - hframe;
+		     max = srcbox->BxYOrg + srcbox->BxHeight -
+		                            pFrame->FrYOrg - hframe;
 		  if (pAbb->AbTruncatedHead)
 		     y = delta;
 		  else
 		    {
 		       y = -pFrame->FrYOrg;
-		       /* Il faut respecter la marge initiale si elle est positive */
+		       /* Il faut respecter la marge initiale si elle est
+			  positive */
 		       if (srcbox->BxYOrg < 0)
 			  y += srcbox->BxYOrg;
 		    }
 
-		  /* Le Scroll est possible --> Calcule l'amplitude du Scroll */
+		  /* Le Scroll est possible --> Calcule l'amplitude du Scroll*/
 		  if ((delta > 0 && max > 0) || (delta < 0 && y < 0))
+		    {
 		     if (delta > 0)
 		       {
 			  /* SCROLL AVANT */
@@ -129,8 +115,8 @@ int                 selection;
 			  DefClip (frame, pFrame->FrXOrg, height + delta,
 				   pFrame->FrXOrg + lframe, height);
 			  add = RedrawFrameTop (frame, -delta);
-			  /* On reallume eventuellement une selection cachee */
 		       }
+		    }
 
 		  /* recompute scrolls */
 		  CheckScrollingWidth (frame);
@@ -159,17 +145,7 @@ int                 selection;
    Le parametre selection indique s'il faut gerer la       
    selection (valeur 1) ou non (valeur 0).                 
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                HorizontalScroll (int frame, int delta, int selection)
-
-#else  /* __STDC__ */
-void                HorizontalScroll (frame, delta, selection)
-int                 frame;
-int                 delta;
-int                 selection;
-
-#endif /* __STDC__ */
-
+void HorizontalScroll (int frame, int delta, int selection)
 {
   int                 x, height;
   int                 min, max, width;
@@ -191,7 +167,7 @@ int                 selection;
 	  /* Right limit is the current scroll width + extra */
 	  max = min + FrameTable[frame].FrScrollWidth - lframe;
 	  /* Left limit is the current scroll width - extra */
-	  /* keep the right margin if the document is smaller than the window */
+	  /* keep the right margin if the document is smaller than the window*/
 	  if (srcbox->BxXOrg  < 0)
 	    min += srcbox->BxXOrg;
 
@@ -208,7 +184,8 @@ int                 selection;
 		  width = lframe - x + 1;
 		  Scroll (frame, width, height, x, 0, 0, 0);
 		  width = pFrame->FrXOrg + lframe;
-		  DefClip (frame, width, pFrame->FrYOrg, width + x, pFrame->FrYOrg + hframe);
+		  DefClip (frame, width, pFrame->FrYOrg, width + x,
+			   pFrame->FrYOrg + hframe);
 		}
 	      else
 		{
@@ -219,7 +196,8 @@ int                 selection;
 		  width = lframe - x + 1;
 		  Scroll (frame, width, height, 0, 0, x, 0);
 		  width = pFrame->FrXOrg;
-		  DefClip (frame, width - x, pFrame->FrYOrg, width, pFrame->FrYOrg + hframe);
+		  DefClip (frame, width - x, pFrame->FrYOrg, width,
+			   pFrame->FrYOrg + hframe);
 		}
 
 	      /* display the rest of the window */
@@ -240,15 +218,7 @@ int                 selection;
    Le parame`tre y donne la position demande'e et le       
    parame`tre haut la hauteur de la fenetree^tre.          
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                ShowYPosition (int frame, int y, int height)
-#else  /* __STDC__ */
-void                ShowYPosition (frame, y, height)
-int                 frame;
-int                 y;
-int                 height;
-
-#endif /* __STDC__ */
+void ShowYPosition (int frame, int y, int height)
 {
    ViewFrame          *pFrame;
    PtrBox              pBox;
@@ -271,19 +241,23 @@ int                 height;
 		     JumpIntoView (frame, 0);
 		  else
 		    {
-		       /* Regarde si le cadrage en haut n'est pas deja effectue */
+		       /* Regarde si le cadrage en haut n'est pas deja
+			  effectue */
 		       delta = pBox->BxYOrg - shift;
 		       if (delta < 0)
-			  /* Cadre la boite racine sur le bord gauche de la fenetre */
+			  /* Cadre la boite racine sur le bord gauche de la
+			     fenetre */
 			  VerticalScroll (frame, delta, 1);
 		    }
 	       }
-	     else if (y == height && !pFrame->FrAbstractBox->AbTruncatedTail)	/* cadrage en bas */
+	     else if (y == height && !pFrame->FrAbstractBox->AbTruncatedTail)
+	       /* cadrage en bas */
 	       {
 		  /* Recupere la hauteur de la fenetre */
 		  GetSizesFrame (frame, &delta, &height);
 		  /* Regarde si le cadrage en bas n'est pas deja effectue */
-		  delta = pBox->BxYOrg + pBox->BxHeight - pFrame->FrYOrg - height;
+		  delta = pBox->BxYOrg + pBox->BxHeight - pFrame->FrYOrg -
+		                                                      height;
 		  if (delta > 0)
 		     /* Cadre la boite racine en bas de la fenetreentre */
 		     VerticalScroll (frame, delta, 1);
@@ -321,16 +295,7 @@ int                 height;
    nbCharEnd indique le nombre de carate`res apres l'image abstraite.    
    total indique le nombre total de carate`res du document.        
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-int                 PositionAbsBox (int frame, int *nbCharBegin, int *nbCharEnd, int *total)
-#else  /* __STDC__ */
-int                 PositionAbsBox (frame, nbCharBegin, nbCharEnd, total)
-int                 frame;
-int                *nbCharBegin;
-int                *nbCharEnd;
-int                *total;
-#endif /* __STDC__ */
-
+int PositionAbsBox (int frame, int *nbCharBegin, int *nbCharEnd, int *total)
 {
    ViewFrame          *pFrame;
    PtrBox              premiere;
@@ -352,7 +317,8 @@ int                *total;
    if (pFrame->FrAbstractBox == NULL)
       return -1;
    /* Regarde si l'image est complete */
-   else if (!pFrame->FrAbstractBox->AbTruncatedHead && !pFrame->FrAbstractBox->AbTruncatedTail)
+   else if (!pFrame->FrAbstractBox->AbTruncatedHead &&
+	    !pFrame->FrAbstractBox->AbTruncatedTail)
      {
 	premiere = pFrame->FrAbstractBox->AbBox;
 	*total = premiere->BxHeight;
@@ -363,8 +329,8 @@ int                *total;
 	/* Repere la position de l'image abstraite dans le document */
 	premiere = pFrame->FrAbstractBox->AbBox->BxNext;
 	derniere = pFrame->FrAbstractBox->AbBox->BxPrevious;
-	VolumeTree (pFrame->FrAbstractBox, premiere->BxAbstractBox, derniere->BxAbstractBox,
-		    nbCharBegin, nbCharEnd, total);
+	VolumeTree (pFrame->FrAbstractBox, premiere->BxAbstractBox,
+		    derniere->BxAbstractBox, nbCharBegin, nbCharEnd, total);
 
 	/* L'image se trouve au debut du document ? */
 	if (!pFrame->FrAbstractBox->AbTruncatedHead)
@@ -383,23 +349,11 @@ int                *total;
    dans la fenetree^tre frame.                                     
    La proce'dure rend :                                            
    - Xpos : la position en X du premier cararte`re visualise'.     
-   - Ypos : la position en X du premier cararte`re visualise'.     
+   - Ypos : la position en Y du premier cararte`re visualise'.     
    - width : la largeur de la portion de l'arbre visualise'e.    
    - height : la hauteur de la portion de l'arbre visualise'e.    
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                ComputeDisplayedChars (int frame, int *Xpos, int *Ypos, int *width, int *height)
-
-#else  /* __STDC__ */
-void                ComputeDisplayedChars (frame, Xpos, Ypos, width, height)
-int                 frame;
-int                *Xpos;
-int                *Ypos;
-int                *width;
-raint              *height;
-
-#endif /* __STDC__ */
-
+void ComputeDisplayedChars (int frame, int *Xpos, int *Ypos, int *width, int *height)
 {
    PtrBox              pBoxFirst;
    PtrBox              pBoxLast;
@@ -507,7 +461,8 @@ raint              *height;
    /*      +-------------+                   */
 
    /** Compute the part of the document which is not formatted **/
-   if ((!pFrame->FrAbstractBox->AbTruncatedHead) && (!pFrame->FrAbstractBox->AbTruncatedTail))
+   if ((!pFrame->FrAbstractBox->AbTruncatedHead) &&
+       (!pFrame->FrAbstractBox->AbTruncatedTail))
      {
 	/* The whole document is formatted */
 	if (pFrame->FrYOrg - pBox->BxYOrg <= 0)
@@ -520,7 +475,8 @@ raint              *height;
 	   min = - pFrame->FrYOrg + pBox->BxYOrg;	/* marge haut */
 
 	if (pBox->BxYOrg + pBox->BxHeight <= pFrame->FrYOrg + h)
-	   /* Le bas de l'Picture Concrete + le debordement du bas sont visibles */
+	   /* Le bas de l'Picture Concrete + le debordement du bas sont
+	      visibles */
 	   max = 0;
 	else if (pBox->BxYOrg + pBox->BxHeight >= pFrame->FrYOrg + h)
 	   /* le debordement du bas n'est pas visualible */
@@ -542,13 +498,17 @@ raint              *height;
 	     pBoxFirst = pBox->BxNext;	/* pBoxFirst boite terminale */
 	     pBoxLast = pBox->BxPrevious;	/* pBoxLast boite terminale */
 	     /* Elimine les boites de presentations */
-	     while (pBoxFirst->BxAbstractBox->AbPresentationBox && pBoxFirst != pBoxLast)
+	     while (pBoxFirst->BxAbstractBox->AbPresentationBox &&
+		    pBoxFirst != pBoxLast)
 		pBoxFirst = pBoxFirst->BxNext;
-	     while (pBoxLast->BxAbstractBox->AbPresentationBox && pBoxFirst != pBoxLast)
+	     while (pBoxLast->BxAbstractBox->AbPresentationBox &&
+		    pBoxFirst != pBoxLast)
 		pBoxLast = pBoxLast->BxPrevious;
 
-	     /* Evalue la hauteur et la position Y par rapport a l'image abstraite */
-	     VolumeTree (pFrame->FrAbstractBox, pBoxFirst->BxAbstractBox, pBoxLast->BxAbstractBox, &min, &max, &vtotal);
+	     /* Evalue la hauteur et la position Y par rapport a l'image
+		abstraite */
+	     VolumeTree (pFrame->FrAbstractBox, pBoxFirst->BxAbstractBox,
+			 pBoxLast->BxAbstractBox, &min, &max, &vtotal);
 	     /* min donne le volume qui precede l'Picture Concrete */
 	     /* max donne le volume qui suit l'Picture Concrete */
 
@@ -606,16 +566,7 @@ raint              *height;
    haut de la fenetre et le haut de la boite, exprimee en  
    pourcentage de la hauteur de la fenetre.                
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                ShowBox (int frame, PtrBox pBox, int position, int percent)
-#else  /* __STDC__ */
-void                ShowBox (frame, pBox, position, percent)
-int                 frame;
-PtrBox              pBox;
-int                 position;
-int                 percent;
-
-#endif /* __STDC__ */
+void ShowBox (int frame, PtrBox pBox, int position, int percent)
 {
    int                 ymin, ymax;
    int                 width, height;
@@ -672,14 +623,7 @@ int                 percent;
    Le parame`tre selection indique s'il faut ge'rer la     
    se'lection (valeur 1) ou non (valeur 0).                
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            IsScrolled (int frame, int selection)
-#else  /* __STDC__ */
-ThotBool            IsScrolled (frame, selection)
-int                 frame;
-int                 selection;
-
-#endif /* __STDC__ */
+ThotBool IsScrolled (int frame, int selection)
 {
    int                 xmin, xmax;
    int                 ymin, ymax;
@@ -739,14 +683,7 @@ int                 selection;
    frame et rend cette frame active si l'indicateur actif     
    est Vrai.                                               
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                ShowSelectedBox (int frame, ThotBool actif)
-#else  /* __STDC__ */
-void                ShowSelectedBox (frame, actif)
-int                 frame;
-ThotBool            actif;
-
-#endif /* __STDC__ */
+void ShowSelectedBox (int frame, ThotBool actif)
 {
    ViewFrame          *pFrame;
    PtrBox              pBo1;
@@ -767,7 +704,8 @@ ThotBool            actif;
 	while (pBo1 != NULL && pBo1->BxAbstractBox != NULL &&
 	       pBo1->BxAbstractBox->AbVisibility < pFrame->FrVisibility)
 	  {
-	     if (pBo1->BxAbstractBox->AbSelected || pBo1 == pFrame->FrSelectionBegin.VsBox)
+	     if (pBo1->BxAbstractBox->AbSelected ||
+		 pBo1 == pFrame->FrSelectionBegin.VsBox)
 		pBo1 = pBo1->BxNext;
 	     else
 		return;		/* aucune boite n'est visible */
@@ -789,21 +727,25 @@ ThotBool            actif;
 	       {
 		 if (!pBo1->BxAbstractBox->AbHorizPos.PosUserSpecified)
 		   /* the box position is not given by the user */
+		   {
 		   if (x + dx < xmin + 10)
 		     /* scroll the window */
 		     HorizontalScroll (frame, x + dx - xmin - 10, 0);
 		   else if (x + dx > xmax - 10)
 		     /* scroll the window */
 		     HorizontalScroll (frame, x + dx - xmax + 10, 0);
+		   }
 
 		 if (!pBo1->BxAbstractBox->AbVertPos.PosUserSpecified)
 		   /* the box position is not given by the user */
+		   {
 		   if (y + pBo1->BxHeight < ymin + dy)
 		     /* scroll the window */
 		     VerticalScroll (frame, y + pBo1->BxHeight - ymin - dy, 0);
 		   else if (y > ymax - dy)
 		     /* scroll the window */
 		     VerticalScroll (frame, y - ymax + dy, 0);
+		   }
 	       }
 	  }
      }
@@ -814,14 +756,7 @@ ThotBool            actif;
    IsAbsBoxVisible retourne Vrai si le pAb deborde de la          
    frame du document.                                       
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            IsAbsBoxVisible (int frame, PtrAbstractBox pAb)
-#else  /* __STDC__ */
-ThotBool            IsAbsBoxVisible (frame, pAb)
-int                 frame;
-PtrAbstractBox      pAb;
-
-#endif /* __STDC__ */
+ThotBool IsAbsBoxVisible (int frame, PtrAbstractBox pAb)
 {
    ViewFrame          *pFrame;
    int                 y, ymax;
@@ -832,7 +767,8 @@ PtrAbstractBox      pAb;
       return (FALSE);		/* pas de pave a tester */
    else if (pAb->AbBox == NULL)
       return (FALSE);		/* pas de boite a tester */
-   else if (pAb->AbVisibility < pFrame->FrVisibility || pAb->AbBox->BxType == BoGhost)
+   else if (pAb->AbVisibility < pFrame->FrVisibility ||
+	    pAb->AbBox->BxType == BoGhost)
       return (FALSE);		/* la boite n'est pas visible par definition */
    else
      {
