@@ -1,19 +1,10 @@
 /*
  *
- *  (c) COPYRIGHT MIT and INRIA, 1996.
+ *  (c) COPYRIGHT MIT and INRIA, 1996-2001.
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
-/*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
 #ifndef _APPLICATION_H_
 #define _APPLICATION_H_
 
@@ -68,7 +59,6 @@
 #define ERR_language_not_found 		101
 
 #ifndef __CEXTRACT__
-#ifdef __STDC__
 
 
 /*----------------------------------------------------------------------
@@ -80,7 +70,7 @@
    from the tool kit.  This name is used for accessing the ressources
    defined in file .Xdefaults.
   ----------------------------------------------------------------------*/
-extern void TtaInitialize (CHAR_T* applicationName);
+extern void TtaInitialize (char *applicationName);
 
 /*----------------------------------------------------------------------
    TtaSetApplicationQuit register the procedure that must be called
@@ -89,6 +79,12 @@ extern void TtaInitialize (CHAR_T* applicationName);
   ----------------------------------------------------------------------*/
 extern void TtaSetApplicationQuit (Proc procedure);
 
+/*----------------------------------------------------------------------
+  TtaSetEntityFunction registers the function that gives entity names.
+  procedure (int entityValue, char **entityName)
+  ----------------------------------------------------------------------*/
+void TtaSetEntityFunction (Proc procedure);
+
 /*----------------------------------------------------------------------
    TtaQuit
    Quits the Thot tool kit. No other function of the tool kit can then
@@ -110,7 +106,7 @@ extern void TtaSetErrorMessages (int on);
    Return value:
    identifier of the current version.
   ----------------------------------------------------------------------*/
-extern STRING TtaGetVersion (void);
+extern char *TtaGetVersion (void);
 
 /*----------------------------------------------------------------------
    TtaGetErrorCode
@@ -130,7 +126,7 @@ extern int TtaGetErrorCode (void);
    No return value
    See also: TtaGetErrorCode
   ----------------------------------------------------------------------*/
-extern STRING TtaGetStrError (int errorCode);
+extern char *TtaGetStrError (int errorCode);
 
 /*----------------------------------------------------------------------
    TtaExtractName: extracts the directory and the file name.       
@@ -138,7 +134,7 @@ extern STRING TtaGetStrError (int errorCode);
    which sizes are sufficient to contain the path and      
    the file name.                                          
   ----------------------------------------------------------------------*/
-extern void TtaExtractName (CHAR_T* text, /*OUT*/ CHAR_T* aDirectory, /*OUT*/ CHAR_T* aName);
+extern void TtaExtractName (char *text, char *aDirectory, char *aName);
 
 /*----------------------------------------------------------------------
    TtaIsPrinting returns TRUE is the application is printing.    
@@ -147,33 +143,9 @@ extern ThotBool TtaIsPrinting ();
 
 extern void*     TtaGetMemory (unsigned int size);
 extern void      TtaFreeMemory (void *buffer);
-extern STRING    TtaAllocString ( unsigned int n );
 extern void*     TtaRealloc (void *ptr, unsigned int n);
 extern char*     TtaStrdup (char* str);
-extern CHAR_T*   TtaWCSdup (CHAR_T* str);
-extern char*     TtaWC2ISOdup (CHAR_T* str);
-extern CHAR_T*   TtaISO2WCdup (char* str);
 
-#else  /* __STDC__ */
-extern void      TtaInitialize ( /* CHAR_T* applicationName */ );
-extern void      TtaSetApplicationQuit (/* Proc procedure */);
-extern void      TtaQuit ( /* void */ );
-extern void      TtaSetErrorMessages ( /* int on */ );
-extern STRING    TtaGetVersion ( /* void */ );
-extern int       TtaGetErrorCode ( /* void */ );
-extern STRING    TtaGetStrError ( /* int errorCode */ );
-extern void      TtaExtractName ( /* CHAR_T* text, CHAR_T* aDirectory, CHAR_T* aName */ );
-extern ThotBool  TtaIsPrinting ();
-extern void*     TtaGetMemory ( /* int size */ );
-extern void      TtaFreeMemory ( /* STRING buffer */ );
-extern STRING    TtaAllocString ( /* unsigned int n */ );
-extern void*     TtaRealloc ( /* void *ptr, unsigned int n */ );
-extern char*    TtaStrdup ( /* char *str */ );
-extern CHAR_T*   TtaWCSdup (/* CHAR_T* str */);
-extern char*     TtaWC2ISOdup (/* CHAR_T* str */);
-extern CHAR_T*   TtaISO2WCdup (/* char* str */);
-
-#endif /* __STDC__ */
 #endif /* __CEXTRACT__ */
 
 #endif
