@@ -1,19 +1,10 @@
 /*
  *
- *  (c) COPYRIGHT MIT and INRIA, 1996.
+ *  (c) COPYRIGHT MIT and INRIA, 1996-2001.
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
-/*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
 #ifndef _INTERFACE_H_
 #define _INTERFACE_H_
 
@@ -37,14 +28,37 @@ extern int          TtaUseOwnXLookupString;
 #define Graphic_keyboard		3
 
 #ifndef __CEXTRACT__
-#ifdef __STDC__
+/*----------------------------------------------------------------------
+  TtaSetCopyAndCutFunction registers the copy & cut function
+  ----------------------------------------------------------------------*/
+extern void TtaSetCopyAndCutFunction (void (*procedure) ());
+
+/*----------------------------------------------------------------------
+  TtaSetAccessKeyFunction registers the access key function.
+  ----------------------------------------------------------------------*/
+extern void TtaSetAccessKeyFunction (void (*procedure) ());
+
+/*----------------------------------------------------------------------
+  TtaAddAccessKey registers a new access key for the document doc
+  The parameter param which will be returned when the access key will be
+  activated.
+  ----------------------------------------------------------------------*/
+extern void TtaAddAccessKey (Document doc, unsigned int key, void *param);
+
+/*----------------------------------------------------------------------
+  TtaRemoveDocAccessKeys removes all access keys of a document.
+  ----------------------------------------------------------------------*/
+extern void TtaRemoveDocAccessKeys (Document doc);
+
+/*----------------------------------------------------------------------
+  TtaRemoveAccessKey removes an access key of a document.
+  ----------------------------------------------------------------------*/
+extern void TtaRemoveAccessKey (Document doc, unsigned int key);
 
 /*----------------------------------------------------------------------
    TtaAddButton
-
    Adds a new button entry in a document view.
    This function must specify a valid view of a valid document.
-
    Parameters:
    document: the concerned document.
    view: the concerned view.
@@ -57,15 +71,13 @@ extern int          TtaUseOwnXLookupString;
    state: TRUE to enable the button, false to disable it.
    Returns index
   ----------------------------------------------------------------------*/
-extern int          TtaAddButton (Document document, View view, ThotIcon picture, void (*procedure) (), char* functionName, STRING info, BYTE type, ThotBool state);
+extern int TtaAddButton (Document document, View view, ThotIcon picture, void (*procedure) (), char* functionName, char *info, unsigned char type, ThotBool state);
 
 /*----------------------------------------------------------------------
    TtaGetButtonCallback
-
    Get the callback of a button in a document view.
    Returns the callback if it exists
            NULL if it doesn't exists
-
    Parameters:
    document: the concerned document.
    view: the concerned view.
@@ -75,23 +87,19 @@ extern void *TtaGetButtonCallback (Document document, View view, int index);
 
 /*----------------------------------------------------------------------
    TtaSwitchButton
-
    Change the status of the button entry in a document view.
    This function must specify a valid view of a valid document.
-
    Parameters:
    document: the concerned document.
    view: the concerned view.
    index: the index.
   ----------------------------------------------------------------------*/
-extern void         TtaSwitchButton (Document document, View view, int index);
+extern void TtaSwitchButton (Document document, View view, int index);
 
 /*----------------------------------------------------------------------
    TtaChangeButton
-
    Change the button entry in a document view.
    This function must specify a valid view of a valid document.
-
    Parameters:
    document: the concerned document.
    view: the concerned view.
@@ -99,14 +107,12 @@ extern void         TtaSwitchButton (Document document, View view, int index);
    picture: the new icon.
    state: TRUE to enable the button, false to disable it.
   ----------------------------------------------------------------------*/
-extern void         TtaChangeButton (Document document, View view, int index, ThotIcon picture, ThotBool state);
+extern void TtaChangeButton (Document document, View view, int index, ThotIcon picture, ThotBool state);
 
 /*----------------------------------------------------------------------
    TtaAddTextZone
-
    Adds a new textual command in a document view.
    This function must specify a valid view of a valid document.
-
    Parameters:
    document: the concerned document.
    view: the concerned view.
@@ -114,55 +120,51 @@ extern void         TtaChangeButton (Document document, View view, int index, Th
    procedure: procedure to be executed when the new entry is changed by the
    user.
   ----------------------------------------------------------------------*/
-extern int          TtaAddTextZone (Document document, View view, STRING label, ThotBool editable, void (*procedure) ());
+extern int TtaAddTextZone (Document document, View view, char *label, ThotBool editable, void (*procedure) ());
 
 /*----------------------------------------------------------------------
    TtaSetTextZone
-
    Sets the text in text-zone in a document view.
    This function must specify a valid view of a valid document.
-
    Parameters:
    document: identifier of the document.
    view: identifier of the view.
    index: 
-
   ----------------------------------------------------------------------*/
-extern void         TtaSetTextZone (Document document, View view, int index, STRING text);
+extern void TtaSetTextZone (Document document, View view, int index, char *text);
 
 /*----------------------------------------------------------------------
    TtaSetMenuOff desactive le menu (1 a n) de la vue du document ou   
    de la fenetre principale (document = 0, view = 0).                 
   ----------------------------------------------------------------------*/
-extern void         TtaSetMenuOff (Document document, View view, int menuID);
+extern void TtaSetMenuOff (Document document, View view, int menuID);
 
 /*----------------------------------------------------------------------
    TtaSetMenuOn reactive le menu (1 a n) de la vue du document ou     
    de la fenetre principale (document = 0, view = 0).                 
   ----------------------------------------------------------------------*/
-extern void         TtaSetMenuOn (Document document, View view, int menuID);
+extern void TtaSetMenuOn (Document document, View view, int menuID);
 
 /*----------------------------------------------------------------------
    TtaSetToggleItem positionne l'item du menu de la vue du document   
    ou de la fenetre principale (document = 0, view = 0).   
   ----------------------------------------------------------------------*/
-extern void         TtaSetToggleItem (Document document, View view, int menuID, int itemID, ThotBool on);
+extern void TtaSetToggleItem (Document document, View view, int menuID, int itemID, ThotBool on);
 
 /*----------------------------------------------------------------------
    TtaSetItemOff desactive l'item actionName de la vue du document  
    ou de la fenetre principale (document = 0, view = 0).   
   ----------------------------------------------------------------------*/
-extern void         TtaSetItemOff (Document document, View view, int menuID, int itemID);
+extern void TtaSetItemOff (Document document, View view, int menuID, int itemID);
 
 /*----------------------------------------------------------------------
    TtaSetItemOn active l'item actionName de la vue du document      
    ou de la fenetre principale (document = 0, view = 0).   
   ----------------------------------------------------------------------*/
-extern void         TtaSetItemOn (Document document, View view, int menuID, int itemID);
+extern void TtaSetItemOn (Document document, View view, int menuID, int itemID);
 
 /*----------------------------------------------------------------------
    TtaSetCallback
-
    Specifies the procedure that is called when the user activates a set of forms
    and/or menus created by the application.
    The parameter set gives the number of forms and/or menus created by the 
@@ -172,171 +174,136 @@ extern void         TtaSetItemOn (Document document, View view, int menuID, int
    This function replaces the DefineCallback function in the Dialogue tool kit.
    This procedure is called with three parameters: the menu or form reference,
    data type, and data value.
-
    void callbakProcedure(reference, datatype, data)
    int reference;
    int datatype;
-   STRING data; 
-
+   char *data; 
    Parameter:
    callbakProcedure: the application callback procedure.
    set: the number of forms and/or menus managed.
    Return:
    reference of the first form or menu.
   ----------------------------------------------------------------------*/
-extern int          TtaSetCallback (void (*callbakProcedure) (), int set);
+extern int TtaSetCallback (void (*callbakProcedure) (), int set);
 
 /*----------------------------------------------------------------------
    TtaSetStatus affiche le status de la vue du document.                      
   ----------------------------------------------------------------------*/
-extern void         TtaSetStatus (Document document, View view, CONST STRING text, CONST STRING name);
+extern void TtaSetStatus (Document document, View view, char *text, char *name);
 
 /*----------------------------------------------------------------------
    TtaGetViewFrame retourne le widget du frame de la vue document.    
   ----------------------------------------------------------------------*/
-extern ThotWidget   TtaGetViewFrame (Document document, View view);
+extern ThotWidget TtaGetViewFrame (Document document, View view);
+
+
+/*----------------------------------------------------------------------
+   TtaMainLoop
+   The application main event loop
+  ----------------------------------------------------------------------*/
+extern void TtaMainLoop (void);
+
+/*----------------------------------------------------------------------
+    TtaHandlePendingEvents
+    Processes all pending events in an application.
+  ----------------------------------------------------------------------*/
+extern void TtaHandlePendingEvents ();
+
+/*----------------------------------------------------------------------
+   TtaClickElement
+   Returns document and element clicked.
+  ----------------------------------------------------------------------*/
+extern void TtaClickElement (/*OUT*/ Document *document, /*OUT*/ Element *element);
+
+/*----------------------------------------------------------------------
+  ----------------------------------------------------------------------*/
+extern Pixmap TtaCreatePixmapLogo (char **data);
+
+/*----------------------------------------------------------------------
+  TtaCreateBitmapLogo
+  Creates a logo pixmap from a bitmap description: width, height and bit array.
+  Parameters:
+  width: the width value of the bitmap.
+  height: the height value of the bitmap.
+  bits: the bit array.
+  Return value:
+  The created pixmap for the logo.
+  ----------------------------------------------------------------------*/
+extern Pixmap TtaCreateBitmapLogo (int width, int height, char* bits);
+
+extern void TtaSetCursorWatch (Document document, View view);
+extern void TtaResetCursor (Document document, View view);
+
+/*----------------------------------------------------------------------
+   TtaGetMenuColor
+   Returns the color used for the background of dialogue windows.
+  ----------------------------------------------------------------------*/
+extern Pixel TtaGetMenuColor (void);
+
+/*----------------------------------------------------------------------
+  TtaUpdateEditorColors
+  Updates the current foreground and background (text and menus) from
+  the values stored in the registry.
+  ----------------------------------------------------------------------*/
+extern void TtaUpdateEditorColors (void);
+
+/*----------------------------------------------------------------------
+   TtaGetScreenDepth
+   Returns the current screen depth.
+  ----------------------------------------------------------------------*/
+extern int TtaGetScreenDepth (void);
 
 #ifndef _WINDOWS
 /*----------------------------------------------------------------------
    TtaFetchOneEvent
-
    retrieve one X-Windows Event from the queue, this is a blocking call.
   ----------------------------------------------------------------------*/
-extern void         TtaFetchOneEvent (ThotEvent *ev);
+extern void TtaFetchOneEvent (ThotEvent *ev);
+/*----------------------------------------------------------------------
+   TtaFetchOneAvailableEvent
+
+   retrieve one X-Windows Event from the queue if one is immediately
+   available.
+  ----------------------------------------------------------------------*/
+ThotBool TtaFetchOneAvailableEvent (ThotEvent *ev);
 /*----------------------------------------------------------------------
    TtaHandleOneEvent
-
    process an X-Windows Event.
   ----------------------------------------------------------------------*/
-extern void         TtaHandleOneEvent (ThotEvent * ev);
-extern int          TtaXLookupString (ThotKeyEvent * event, STRING buffer, int nbytes,
-				  KeySym * keysym, ThotComposeStatus * status);
+extern void TtaHandleOneEvent (ThotEvent *ev);
 
-#endif /* !_WINDOWS */
-
-/*----------------------------------------------------------------------
-   TtaMainLoop
-
-   The application main event loop
-  ----------------------------------------------------------------------*/
-extern void         TtaMainLoop (void);
-
-/*----------------------------------------------------------------------
-   * TtaHandlePendingEvents
- *
-   * Processes all pending events in an application.
-  ----------------------------------------------------------------------*/
-extern void         TtaHandlePendingEvents ();
-
-/*----------------------------------------------------------------------
-   TtaClickElement
-
-   Returns document and element clicked.
-
-  ----------------------------------------------------------------------*/
-extern void         TtaClickElement (/*OUT*/ Document *document, /*OUT*/ Element *element);
-extern Pixmap       TtaCreatePixmapLogo (char** data);
-
-/*----------------------------------------------------------------------
-   TtaCreateBitmapLogo
-
-   Creates a logo pixmap from a bitmap description: width, height and bit array.
-
-   Parameters:
-   width: the width value of the bitmap.
-   height: the height value of the bitmap.
-   bits: the bit array.
-
-   Return value:
-   The created pixmap for the logo.
-
-  ----------------------------------------------------------------------*/
-extern Pixmap       TtaCreateBitmapLogo (int width, int height, char* bits);
-extern void         TtaSetCursorWatch (Document document, View view);
-extern void         TtaResetCursor (Document document, View view);
-
-/*----------------------------------------------------------------------
-   TtaGetMenuColor
-
-   Returns the color used for the background of dialogue windows.
-  ----------------------------------------------------------------------*/
-extern Pixel        TtaGetMenuColor (void);
-
-/*----------------------------------------------------------------------
-  TtaUpdateEditorColors
-  
-  Updates the current foreground and background (text and menus) from
-  the values stored in the registry.
-  ----------------------------------------------------------------------*/
-extern void         TtaUpdateEditorColors (void);
-
-/*----------------------------------------------------------------------
-   TtaGetScreenDepth
-
-   Returns the current screen depth.
-
-  ----------------------------------------------------------------------*/
-extern int          TtaGetScreenDepth (void);
-
-#ifndef _WINDOWS
-extern Display     *TtaGetCurrentDisplay (void);
+extern int TtaXLookupString (ThotKeyEvent *event, char *buffer, int nbytes,
+			     KeySym *keysym, ThotComposeStatus *status);
 
+extern Display *TtaGetCurrentDisplay (void);
 #endif /* !_WINDOWS */
 
 /*----------------------------------------------------------------------
    TtaGiveSelectPosition: returns the mouse position for the last click 
    with respect to the element (position in pixel)            
   ----------------------------------------------------------------------*/
-extern void         TtaGiveSelectPosition (Document document, Element element, View view, /*OUT*/ int *X, /*OUT*/ int *Y);
+extern void TtaGiveSelectPosition (Document document, Element element, View view, /*OUT*/ int *X, /*OUT*/ int *Y);
 
 /*----------------------------------------------------------------------
    TtaSetMultiKey
-
    Enables or disables the multikey support
-
    Parameters:
    value : TRUE/FALSE
-
   ----------------------------------------------------------------------*/
-extern void         TtaSetMultikey ( ThotBool value );
-
-#else  /* __STDC__ */
-
-extern int          TtaAddButton (/*Document document, View view, ThotIcon picture, void (*procedure) (), STRING functionName, STRING info, BYTE type, ThotBool state*/);
-extern void        *TtaGetButtonCallback ( /*Document document, View view, int index */);
-extern void         TtaSwitchButton ( /*Document document, View view, int index */ );
-extern void         TtaChangeButton ( /*Document document, View view, int index, ThotIcon picture, ThotBool state */ );
-extern int          TtaAddTextZone ( /*Document document, View view, STRING label, ThotBool editable, void (*procedure) () */ );
-extern void         TtaSetTextZone ( /*Document document, View view, int index, STRING text */ );
-extern void         TtaSetMenuOff ( /*Document document, View view, int menuID */ );
-extern void         TtaSetMenuOn ( /*Document document, View view, int menuID */ );
-extern void         TtaSetToggleItem ( /*Document document, View view, int menuID, int itemID, ThotBool on */ );
-extern void         TtaSetItemOff ( /*Document document, View view, int menuID, int itemID */ );
-extern void         TtaSetItemOn ( /*Document document, View view, int menuID, int itemID */ );
-extern int          TtaSetCallback ( /*void (*callbakProcedure) (), int set */ );
-
-#ifndef _WINDOWS
-extern void         TtaFetchOneEvent ( /*ThotEvent *ev */ );
-extern void         TtaHandleOneEvent ( /*ThotEvent *ev */ );
-extern int          TtaXLookupString (	/* ThotKeyEvent *event, STRING buffer, int nbytes,
-					   KeySym *keysym, ThotComposeStatus *status */ );
-
-#endif /* !_WINDOWS */
-extern void         TtaMainLoop ( /* void */ );
-extern void         TtaHandlePendingEvents ();
-extern void         TtaClickElement ( /*Document *document, Element *element */ );
-extern Pixmap       TtaCreatePixmapLogo ( /*STRING *data */ );
-extern Pixmap       TtaCreateBitmapLogo ( /*int width, int height, STRING bits */ );
-extern void         TtaSetCursorWatch ( /*Document document, View view */ );
-extern void         TtaResetCursor ( /*Document document, View view */ );
-extern Pixel        TtaGetMenuColor ( /* void */ );
-extern void         TtaUpdateEditorColors ( /* void */ );
-extern Pixel        TtaGetButtonColor ( /* void */ );
-extern int          TtaGetScreenDepth ( /* void */ );
-extern Display     *TtaGetCurrentDisplay ( /* void */ );
-extern void         TtaGiveSelectPosition ( /* Document document, Element element, View view, int *X, int *Y */ );
-extern void         TtaSetMultikey (/* ThotBool value*/);
-#endif /* __STDC__ */
+extern void TtaSetMultikey ( ThotBool value );
+/*----------------------------------------------------------------------
+   TtaSetMultiKey
+   Return the state of the multikey support
+   Parameters:
+   value :
+  ----------------------------------------------------------------------*/
+extern ThotBool TtaGetMultikey();
 #endif /* __CEXTRACT__ */
 
+/*----------------------------------------------------------------------
+  BuildMenus builds or rebuilds frame menus.
+  The parameter RO is TRUE when only ReadOnly functions are accepted
+  ----------------------------------------------------------------------*/
+extern void TtaUpdateMenus (Document doc, View view, ThotBool RO);
+
 #endif
