@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996-2000
+ *  (c) COPYRIGHT INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -62,7 +62,7 @@ typedef enum
 /* Kind of object used as a reference in a relative position */
 typedef enum
 {
-  RkElType, RkPresBox, RkAttr
+  RkElType, RkPresBox, RkAttr, RkAnyElem, RkAnyBox
 } RefKind;
 
 /* relative positionning rule for the dimensions or axes of two boxes */
@@ -145,63 +145,56 @@ typedef struct _DimensionRule
 /* type of the content of a presentation box */
 typedef enum
 {
-    FreeContent, ContVariable, ContConst, ContElement
+    FreeContent, ContVariable, ContConst
 }	ContentType;
 
 /* a presentation box */
 typedef struct _PresentationBox
 {
-  Name      PbName;		  /* box name */	
-  PtrPRule	PbFirstPRule;	  /* first presentation rule defining the box*/
-  ThotBool	PbAcceptPageBreak;/* indicates whether the box may be
-				     broken at the bottom of a page */
-  ThotBool	PbAcceptLineBreak;/* indicates whether the box may be
-				     broken at the end of a line */
-  ThotBool	PbBuildAll;	  /* indicates if the box image must be built
-				     in one piece or if it can be partial */
-  ThotBool	PbPageFooter;	  /* it is a footer box */
-  ThotBool	PbPageHeader;	  /* it is a header box */
-  ThotBool	PbPageBox;	  /* it is a page box */
-  int	 	PbFooterHeight;	  /* if it is a page box, size of the footer
-				     in picas */
-  int		PbHeaderHeight;	  /* if it is a page box, size of the header
-				     in picas */
-  int		PbPageCounter;	  /* number of the page counter, only if
-				     PbPageBox is true */
-  ContentType	PbContent;	  /* compulsory box content */
+  Name         PbName;		 /* box name */	
+  PtrPRule     PbFirstPRule;	 /* first presentation rule defining the box*/
+  ThotBool     PbPageFooter;	 /* it is a page footer box */
+  ThotBool     PbPageHeader;	 /* it is a page header box */
+  ThotBool     PbPageBox;	 /* it is a page box */
+  int	       PbFooterHeight;	 /* if it is a page box, size of the footer
+				    in picas */
+  int	       PbHeaderHeight;	 /* if it is a page box, size of the header
+				    in picas */
+  int	       PbPageCounter;	 /* number of the page counter, only if
+				    PbPageBox is true */
+  ContentType  PbContent;	 /* compulsory box content */
   union
   {
-    struct			  /* PbContent = ContVariable */
+    struct			 /* PbContent = ContVariable */
     {
-      int	_PbContVariable_; /* number of the variable */
+      int      _PbContVariable_; /* number of the variable */
     }   s0;
-    struct			  /* PbContent = ContConst */
+    struct			 /* PbContent = ContConst */
     {
-      int	_PbContConstant_; /* number of the constant */
+      int      _PbContConstant_; /* number of the constant */
     } s1;
-    struct			  /* PbContent = ContElement */
+    struct			 /* PbContent = FreeContent */
     {
-      int	_PbContElem_;	  /* number of the element type */
-      int	_PbContRefElem_;  /* number of the type of reference to this
-				     element */
+      int      _PbContFree_;     /* to make the compiler happy */
     } s2;
-    struct			  /* PbContent = FreeContent */
-    {
-      CHAR_T	_PbContFree_;     /* to make the compiler happy */
-    } s3;
   } u;
 } PresentationBox;
 
 #define PbContVariable u.s0._PbContVariable_
 #define PbContConstant u.s1._PbContConstant_
-#define PbContElem u.s2._PbContElem_
-#define PbContRefElem u.s2._PbContRefElem_
-#define PbContFree u.s3._PbContFree_
+#define PbContFree u.s2._PbContFree_
+
+typedef struct _PresentationBox *PtrPresentationBox;
+
+typedef struct _PresBoxTable
+{
+  PtrPresentationBox  PresBox[1];
+} PresBoxTable;
 
 /* Alignment of the lines in an abstract box */
 typedef enum
 {
-  AlignLeft, AlignRight, AlignCenter, AlignLeftDots
+  AlignLeft, AlignRight, AlignCenter, AlignLeftDots, AlignJustify
 } BAlignment;	/* AlignLeftDots = aligned to the left, the last
 		   line is filled with dots */
 
@@ -210,6 +203,7 @@ typedef enum
 {
   /* the order determines the order of the rules in the presentation schema */
   /* Don't forget to change constant MAX_TRANSL_PRULE when adding rules */
+  /* Don't forget to update PR values in the file presentation.h */
   PtVisibility, PtFunction, PtVertRef, PtHorizRef, PtHeight, PtWidth, 
   PtVertPos, PtHorizPos,
   PtMarginTop, PtMarginRight, PtMarginBottom, PtMarginLeft,
@@ -218,10 +212,10 @@ typedef enum
   PtBorderTopColor, PtBorderRightColor, PtBorderBottomColor, PtBorderLeftColor,
   PtBorderTopStyle, PtBorderRightStyle, PtBorderBottomStyle, PtBorderLeftStyle,
   PtSize, PtStyle, PtWeight, PtFont, PtUnderline, PtThickness,
-  PtIndent, PtLineSpacing, PtDepth, PtAdjust, PtJustify,
+  PtIndent, PtLineSpacing, PtDepth, PtAdjust,
   PtLineStyle, PtLineWeight, PtFillPattern, PtBackground, PtForeground,
-  PtHyphenate, PtVertOverflow, PtHorizOverflow,
-  PtXRadius, PtYRadius,
+  PtHyphenate, PtVertOverflow, PtHorizOverflow, PtPageBreak, PtLineBreak,
+  PtGather, PtXRadius, PtYRadius,
   /* the three following types must be the last ones */
   PtBreak1, PtBreak2, PtPictInfo
 } PRuleType;
@@ -272,33 +266,33 @@ typedef enum
 typedef struct _PresVarItem
 {
   VariableType     ViType;
-  CounterStyle  ViStyle;	/* digit style for VarCounter, VarAttrValue and
-				   VarPageNumber */
+  CounterStyle  ViStyle;           /* digit style for VarCounter, VarAttrValue
+				      and VarPageNumber */
   union
   {
     struct
     {
-      int	     _ViConstant_;	/* number of the constant */ 
+      int	   _ViConstant_;   /* number of the constant */ 
     } s0;
     struct
     {
-      int	     _ViCounter_;   	/* number of the counter */
-      CounterValue _ViCounterVal_; 	/* indicates if we are interested in
-					   the maximum, minimum or current
-					   value of the counter */
+      int	   _ViCounter_;    /* number of the counter */
+      CounterValue _ViCounterVal_; /* indicates if we are interested in the
+				      maximum, minimum or current value of
+				      the counter */
     } s1;
     struct
     {
-      int  _ViAttr_;  	/* the attribute number */
+      int          _ViAttr_;  	   /* the attribute number */
     } s2;
     struct
     {
-      int            _ViDate_;      /* for the compiler */
+      int          _ViDate_;       /* for the compiler */
     } s3;
-    struct			    /* ViType = VarPageNumber */
+    struct			   /* ViType = VarPageNumber */
     {
-      int	     _ViView_;	/* number of the view in which pages are
-				   counted */
+      int	   _ViView_;	   /* number of the view in which pages are
+				      counted */
     } s4;
   } u;
 } PresVarItem;
@@ -315,8 +309,9 @@ typedef enum
 {
   PcFirst, PcLast, PcReferred, PcFirstRef, PcLastRef, PcExternalRef,
   PcInternalRef, PcCopyRef, PcAnyAttributes, PcFirstAttr, PcLastAttr,
-  PcUserPage, PcStartPage, PcComputedPage, PcEmpty, PcEven, PcOdd, PcOne,
-  PcInterval, PcWithin, PcElemType, PcAttribute, PcNoCondition, PcDefaultCond
+  PcUserPage, PcStartPage, PcComputedPage, PcEmpty, PcRoot, PcEven,
+  PcOdd, PcOne, PcInterval, PcWithin, PcElemType, PcAttribute,
+  PcNoCondition, PcDefaultCond
 } PresCondition;
 
 /* To interpret the field CoRelation */
@@ -330,46 +325,43 @@ typedef struct _Condition *PtrCondition;
 /* A presentation rule application condition */
 typedef struct _Condition
 {
-  PtrCondition    CoNextCondition;	/* Next condition in the list
-					   IF cond AND cond AND cond ... */
-  PresCondition   CoCondition;	        /* type of the condition */	
-  ThotBool        CoNotNegative;	/* the condition is not negative */
-  ThotBool	  CoTarget;		/* the condition affects the target
-					   (for references only) */
+  PtrCondition    CoNextCondition; /* Next condition in the list
+				      IF cond AND cond AND cond ... */
+  PresCondition   CoCondition;	   /* type of the condition */	
+  ThotBool        CoNotNegative;   /* the condition is not negative */
+  ThotBool	  CoTarget;	   /* the condition affects the target
+				      (for references only) */
   union
   {
-    struct				/* CoCondition = PcInterval, PcEven,
-					   PcOdd, PcOne */
+    struct			   /* CoCondition = PcInterval, PcEven, PcOdd,
+				      PcOne */
     {
-      int	  _CoCounter_; 	  /* number of the counter on which the
-				     condition applies */
-      int	  _CoMinCounter_; /* minimum value of the counter so that
+      int	   _CoCounter_;    /* number of the counter on which the
+				      condition applies */
+      int	   _CoMinCounter_; /* minimum value of the counter so that
 				     the presentation rule may be applied */
-      int	  _CoMaxCounter_; /* maximum value of the counter so that
-				     the presentation rule may be applied */
-      CounterValue _CoValCounter_; 	/* indicates if the minimum, maximum
-					   or current value of the counter is
-					   used */
+      int	   _CoMaxCounter_; /* maximum value of the counter so that
+				      the presentation rule may be applied */
+      CounterValue _CoValCounter_; /* indicates if the minimum, maximum or
+				      current value of the counter is used */
     } s0;
-    struct				/* CoCondition = PcWithin */
+    struct			   /* CoCondition = PcWithin */
     {
-      int       _CoRelation_;		/* RelLevel */
-      int       _CoTypeAncestor_;	/* type of the ancestor */	
-      ThotBool  _CoImmediate_;	/* Immediately */
+      int       _CoRelation_;	   /* RelLevel */
+      int       _CoTypeAncestor_;  /* type of the ancestor */	
+      ThotBool  _CoImmediate_;	   /* Immediately */
       ArithRel  _CoAncestorRel_;
-      Name      _CoAncestorName_;	/* Ancestor type name, if defined
-					   in another schema */
-      Name      _CoSSchemaName_;	/* name of the schema where the
-					   ancestor is defined if
-					   CoTypeAncestor = 0 */
+      Name      _CoAncestorName_;  /* Ancestor type name, if defined in
+				      another schema */
+      Name      _CoSSchemaName_;   /* name of the schema where the ancestor is
+				      defined if CoTypeAncestor == 0 */
     } s1;
-    struct				/* CoCondition = PcElemType or
-					   PcAttribute */
+    struct			   /* CoCondition = PcElemType or PcAttribute*/
     {
-      int	  _CoTypeElAttr_;	/* PcElemType: type of the element
-					   to which the attribute is attached.
-					   PcAttribute: attribute carried by
-					   the element */
+      int	_CoTypeElAttr_;	   /* PcElemType: type of the element to which
+				      the attribute is attached.
+				      PcAttribute: attribute carried by the
+				      element */
     } s2;
   } u;
 } Condition;
@@ -434,20 +426,20 @@ typedef struct _PresRule
       FunctionType _PrPresFunction_;
       ThotBool     _PrPresBoxRepeat_;	/* presentation box repeated over all
 					   the abstract boxes of the element */
-      ThotBool	   _PrExternal_; /* if PrElement is true, PrExternal indicates
-				    that the type of which the name is in
-				    PrPresBoxName is external */
-      ThotBool     _PrElement_;	 /* PrPresBox[1] or PrPresBoxName is an
-				    element type number, not a presentation
-				    box number */
-      int	   _PrNPresBoxes_;	/* number of presentation boxes (of use
-					   for the column rule only) */
+      ThotBool	   _PrExternal_;  /* if PrElement is true, PrExternal indicates
+				     that the type of which the name is in
+				     PrPresBoxName is external */
+      ThotBool     _PrElement_;	  /* PrPresBox[1] or PrPresBoxName is an
+				     element type number, not a presentation
+				     box number */
+      int	   _PrNPresBoxes_;/* number of presentation boxes (of use for
+				     the column rule only) */
       int          _PrPresBox_[MAX_COLUMN_PAGE]; /* number of the
 					            presentation boxes */
-      Name        _PrPresBoxName_;	/* Name of the first (or only) presentation
-					   box to which the function applies */
+      Name        _PrPresBoxName_;/* Name of the first (or only) presentation
+				     box to which the function applies */
     } s1;
-    struct			 /* PrPresMode = PresImmediate */
+    struct			  /* PrPresMode = PresImmediate */
     {
       union
       {
@@ -488,10 +480,10 @@ typedef struct _PresRule
 	{
 	  DimensionRule _PrDimRule_;
 	} s4;
-	struct	/* PRuleType = PtJustify, PtHyphenate, PtVertOverflow,
-		   PtHorizOverflow */
+	struct	/* PRuleType = PtHyphenate, PtVertOverflow,
+		   PtHorizOverflow, PtGather, PtPageBreak, PtLineBreak */
 	{
-	  ThotBool _PrJustify_;
+	  ThotBool _PrBoolValue_;
 	} s5;
 	struct	/* PRuleType = PtAdjust */
 	{
@@ -524,7 +516,7 @@ typedef struct _PresRule
 #define PrMinValue u.s2.u.s2._PrMinValue_
 #define PrPosRule u.s2.u.s3._PrPosRule_
 #define PrDimRule u.s2.u.s4._PrDimRule_
-#define PrJustify u.s2.u.s5._PrJustify_
+#define PrBoolValue u.s2.u.s5._PrBoolValue_
 #define PrAdjust u.s2.u.s6._PrAdjust_
 
 /* operation on a counter */
@@ -594,7 +586,7 @@ typedef struct _PresConstant
 {
   BasicType PdType;                       /* type of the constant */
   char      PdAlphabet;                   /* alphabet of the constant */
-  CHAR_T    PdString[MAX_PRES_CONST_LEN]; /* constant presentation string,
+  char      PdString[MAX_PRES_CONST_LEN]; /* constant presentation string,
 					     terminated by a NUL character */
 } PresConstant;
 
@@ -657,9 +649,9 @@ typedef struct _AttributePres
     struct
     {
       PtrPRule    _ApEnumFirstPRule_[MAX_ATTR_VAL + 1]; /* for each value of
-			   the attribute, in the order of the table AttrEnumValue,
-			   address of the first presentation rule associated
-			   with this value */
+			   the attribute, in the order of the table
+			   AttrEnumValue, address of the first presentation
+			   rule associated with this value */
     } s3;
   } u;
 } AttributePres;
@@ -687,14 +679,9 @@ typedef struct _HostView
 /* description of a view to print */
 typedef struct _PrintedView
 {
-    ThotBool    VpAssoc;	/* it is a view of associated elements */
-    int	 	VpNumber;    	/* number of the view, or of the type of the
-				   associated elements list if VpAssoc. */
+  int	 	VpNumber;    	/* view number */
 } PrintedView;
 
-typedef PtrPRule PtrPRuleTable[MAX_RULES_SSCHEMA];  /* Table of the addresses
-				  of the presentation rules of the Types */
-
 /* a rule of transmission of a value from an element to an included
    document attribute */
 typedef struct _TransmitElem
@@ -706,16 +693,43 @@ typedef struct _TransmitElem
 				   is transmitted */
 } TransmitElem;
 
-typedef ThotBool InheritAttrTable[MAX_ATTR_SSCHEMA];	/* this table is
-                                          attached to an element and
-					  indicates what are the attributes
+typedef ThotBool InheritAttrTable[1];  /* this table is attached to an element
+					  and indicates what are the attributes
 					  that this element inherits */
-typedef ThotBool ComparAttrTable[MAX_ATTR_SSCHEMA]; /* this table is
-					  attached to an element and
-					  indicates what are the attributes
+typedef ThotBool ComparAttrTable[1];   /* this table is attached to an element
+					  and indicates what are the attributes
 					  comparing themselves to it for
 					  presentation */
 
+typedef struct _InheritAttrTbTb
+{
+  InheritAttrTable  *ElInherit[1];
+} InheritAttrTbTb;
+
+typedef struct _CompAttrTbTb
+{
+  ComparAttrTable *CATable[1];
+} CompAttrTbTb;
+
+typedef struct _AttributePres *PtrAttributePres;
+
+typedef struct _AttrPresTable
+{
+  PtrAttributePres  AttrPres[1];
+} AttrPresTable;
+
+typedef struct _PtrPRuleTable
+{
+  PtrPRule ElemPres[1];
+} PtrPRuleTable;
+
+typedef struct _NumberTable
+{
+  int           Num[1];
+} NumberTable;
+
+typedef struct _PresentSchema *PtrPSchema;
+
 /* a presentation schema loaded in memory */
 typedef struct _PresentSchema
 {
@@ -739,92 +753,64 @@ typedef struct _PresentSchema
   int		PsNConstants;		/* number of presentation constants */
   int		PsNVariables;		/* number of presentation variables */
   int		PsNPresentBoxes;	/* number of presentation and layout
-					   boxes */
-  PtrPRule  PsFirstDefaultPRule;	/* beginning of the default rules
+					   boxes that are actually defined */
+  int           PsPresentBoxTableSize;  /* size of table PsPresentBox */
+  PtrPRule      PsFirstDefaultPRule;	/* beginning of the default rules
 					   string */
   Counter       PsCounter[MAX_PRES_COUNTER];  /* counters */
   PresConstant  PsConstant[MAX_PRES_CONST];   /* presentation constants */
   PresVariable  PsVariable[MAX_PRES_VARIABLE];/* presentation variables*/
-  PresentationBox PsPresentBox[MAX_PRES_BOX]; /* descriptions of the
-					   presentation and layout boxes */
+  PresBoxTable  *PsPresentBox;          /* descriptions of the presentation
+					   and layout boxes */
         /* For columns layout, box number 0 contains the Column group box,
 	   box number 1 contains the left-hand column, etc. */
-  AttributePres *PsAttrPRule[MAX_ATTR_SSCHEMA];/* pointers on the presentation
+  AttrPresTable *PsAttrPRule;           /* pointers on the presentation
 					   rules of the logical attributes,
 					   in the same order as in the table
 					   StructSchema.SsAttribute */
-  int		PsNAttrPRule[MAX_ATTR_SSCHEMA]; /* number of presentation rules
+  NumberTable	*PsNAttrPRule;          /* number of presentation rules
 					   packets for each logical attribute,
 					   i.e. size of the strings of
 					   AttributePres in table PsAttrPRule
-					   in the same order as in the table
+					   in the same order as in table
 					   StructSchema.SsAttribute */
-  PtrPRuleTable	PsElemPRule;    	/* pointers on the beginning of the
+  PtrPRuleTable	*PsElemPRule;    	/* pointers on the beginning of the
 					   string of presentation rules related
 					   to each type of element, in the same
-					   order as in tha table
-					   StructSchema.SsRule */
-  int    	PsNHeirElems[MAX_ATTR_SSCHEMA];/* indicates for each attribute,
+					   order as in table SsRule */
+  NumberTable	*PsNHeirElems;         /* indicates for each attribute,
 					  in the same order as in the table
-					  StructSchema.AsAttribute, the number
+					  StructSchema.SsAttribute, the number
 					  of elements that can inherit from the
 					  attribute */
-  int    	PsNInheritedAttrs[MAX_RULES_SSCHEMA]; /* for each element, in
-					  the same order as in the table
-					  StructSchema.SsRule, indicates the
+  NumberTable   *PsNInheritedAttrs;    /* for each element, in the same order
+					  as in table SsRule, indicates the
 					  number of attributes inherited by the
 					  element */
-  InheritAttrTable *PsInheritedAttr[MAX_RULES_SSCHEMA]; /* points for each type
+  InheritAttrTbTb *PsInheritedAttr;    /* points for each type
 					  of element, in the same order as in
 					  the table StructSchema.SsRule, on the
 					  table indicating what are the
 					  attributes inherited by the element*/
-  int    	PsNComparAttrs[MAX_ATTR_SSCHEMA]; /* indicates for each
-					  attribute, in the same order as in
-					  the table StructSchema.SsRule, the
-					  number of attributes comparing
+  NumberTable   *PsNComparAttrs;       /* indicates for each attribute,
+					  in the same order as in
+					  the table StructSchema.SsAttribute,
+					  the number of attributes comparing
 					  themselves to the attribute in order
 					  to deduce the presentation */
-  ComparAttrTable *PsComparAttr[MAX_ATTR_SSCHEMA];/* points for each attribute,
+  CompAttrTbTb  *PsComparAttr;         /* points for each attribute
 					  in the same order as in the table
-					  StructSchema.SsRule, on the table
+					  StructSchema.SsAttribute on the table
 					  indicating which attribute compare
 					  themselves to the attribute in order
 					  to deduce a presentation */
-  ThotBool    PsAcceptPageBreak[MAX_RULES_SSCHEMA]; /* indicates for each
-					  element type, in the same order as in
-					  table StructSchema.SsRule, if the
-					  element can be broken at the bottom
-					  of a page */
-  ThotBool    PsAcceptLineBreak[MAX_RULES_SSCHEMA]; /* indicates for each 
-					  element type, in the same order as in
-					  table StructSchema.SsRule, if the
-					  element can be broken at the end of a
-					  line */
-  ThotBool    PsBuildAll[MAX_RULES_SSCHEMA];    /* indicates for each element
-					  type, in the same order as in
-					  table StructSchema.SsRule, if the
-					  image of the box must be built in one
-					  piece or if it can be divided */
-  ThotBool    PsInPageHeaderOrFooter[MAX_RULES_SSCHEMA]; /* indicates for each
-					  element type, in the same order as
-					  in table StructSchema.SsRule, if
-					  the element is displayed in the body
-					  of the pages (false) or in a footer
-					  or header box (true) */
-  ThotBool    PsAssocPaginated[MAX_RULES_SSCHEMA];/* indicates for each element
-					  type, in the same order as in the
-					  table StructSchema.SsRule, if the
-					  element is paginated (meaningful only
-					  for the associated elements lists) */
-  int	      PsElemTransmit[MAX_RULES_SSCHEMA]; /* for each element type,
-					  in the same order as in table
-					  StructSchema.SsRule, index in the
+  NumberTable   *PsElemTransmit;       /* for each element type, in the same
+					  order as in table SsRule, index in
 					  table SPTransmit of the entry giving
 					  the transmission of the element
 					  values to the attributes of the
 					  included documents */
-  int	      PsNTransmElems;		  /* number of entries in the table
+  int	        PsNTransmElems;	       /* number of entries in the table
 					  PsTransmElem */
   TransmitElem	PsTransmElem[MAX_TRANSM_ELEM];/* table of the transmissions of
 					  the element values to attributes of
