@@ -93,7 +93,11 @@ THOT_EXPORT int        TtWPrinterDepth;	/* Printer color depth           */
 THOT_EXPORT char       TtFontName[MAX_FONT * MAX_FONTNAME];/* font names */
 THOT_EXPORT char       TtPsFontName[MAX_FONT * 8];/* PS font names       */
 THOT_EXPORT int        TtFontFrames[MAX_FONT];
-THOT_EXPORT ptrfont    TtFonts[MAX_FONT];/* loaded fonts                 */
+THOT_EXPORT PtrFont    TtFonts[MAX_FONT];/* loaded fonts                 */
+
+#ifdef _GTK
+THOT_EXPORT ThotCursor ArrowCurs;	/* The base   Cursor             */
+#endif /* _GTK */
 THOT_EXPORT ThotCursor WindowCurs;	/* The window Cursor             */
 THOT_EXPORT ThotCursor WaitCurs;	/* Waiting cursor                */
 THOT_EXPORT ThotCursor VCurs;	/* vertical resizing cursor              */
@@ -105,7 +109,7 @@ THOT_EXPORT int            ClickFrame;	      /* Clicked frame           */
 THOT_EXPORT int            ClickX;	      /* Clicked X position      */
 THOT_EXPORT int            ClickY;	      /* Clicked Y position      */
 THOT_EXPORT int            ClickIsDone;	      /* Click done              */
-THOT_EXPORT USTRING        Xbuffer;	      /* Clipboard buffer        */
+THOT_EXPORT unsigned char *Xbuffer;	      /* Clipboard buffer        */
 THOT_EXPORT int		   ClipboardLength;
 THOT_EXPORT Proc	   CurrentCallbackAPI;
 
