@@ -69,12 +69,12 @@ static void AttachMandatoryAttrSRule (PtrElement pEl, PtrDocument
 
   /* parcourt tous les attributs locaux definis dans la regle */
   for (i = 0; (pDoc->DocSSchema != NULL) && (i < pSRule->SrNLocalAttrs); i++)
-    if (pSRule->SrRequiredAttr[i])
+    if (pSRule->SrRequiredAttr->Bln[i])
       /* cet attribut local est obligatoire */
       if (pDoc->DocSSchema != NULL)
 	/* le document n'a pas ete ferme' entre-temps */
 	{
-	  att = pSRule->SrLocalAttr[i];
+	  att = pSRule->SrLocalAttr->Num[i];
 	  /* cherche si l'element possede cet attribut */
 	  pAttr = pEl->ElFirstAttr;
 	  found = FALSE;
@@ -102,7 +102,7 @@ static void AttachMandatoryAttrSRule (PtrElement pEl, PtrDocument
 	      pAttr->AeAttrSSchema = pSS;
 	      pAttr->AeAttrNum = att;
 	      pAttr->AeDefAttr = FALSE;
-	      pAttr->AeAttrType = pSS->SsAttribute[att - 1].AttrType;
+	      pAttr->AeAttrType = pSS->SsAttribute->TtAttr[att - 1]->AttrType;
 	      switch (pAttr->AeAttrType)
 		{
 		case AtNumAttr:
@@ -171,8 +171,7 @@ static void AttachMandatoryAttrSRule (PtrElement pEl, PtrDocument
 				
 			      case AtTextAttr:
 				/* attribut a valeur textuelle */
-				CopyStringToText (" ", pAttr->AeAttrText,
-						  &len);
+				CopyStringToBuffer (" ", pAttr->AeAttrText, &len);
 				break;
 				
 			      case AtEnumAttr:
@@ -224,7 +223,7 @@ static void AttachMandatoryAttrSRule (PtrElement pEl, PtrDocument
 void AttachMandatoryAttributes (PtrElement pEl, PtrDocument pDoc)
 {
   PtrElement          pChild;
-  SRule              *pSRule;
+  PtrSRule            pSRule;
   PtrSSchema          pSS;
 
   if (pEl != NULL && pEl->ElStructSchema != NULL)
@@ -232,7 +231,7 @@ void AttachMandatoryAttributes (PtrElement pEl, PtrDocument pDoc)
       /* traite d'abord les attributs requis par la regle de structure qui */
       /* definit l'element */
       pSS = pEl->ElStructSchema;
-      pSRule = &pSS->SsRule[pEl->ElTypeNumber - 1];
+      pSRule = pSS->SsRule->SrElem[pEl->ElTypeNumber - 1];
       AttachMandatoryAttrSRule (pEl, pDoc, pSRule, pSS);
       /* traite toutes les regles d'extension de ce type d'element */
       pSS = pDoc->DocSSchema;
@@ -304,7 +303,7 @@ Attribute           TtaNewAttribute (AttributeType attType)
       pAttr->AeAttrNum = attType.AttrTypeNum;
       pAttr->AeDefAttr = FALSE;
       pAttr->AeAttrType =
-              pAttr->AeAttrSSchema->SsAttribute[pAttr->AeAttrNum - 1].AttrType;
+              pAttr->AeAttrSSchema->SsAttribute->TtAttr[pAttr->AeAttrNum - 1]->AttrType;
       switch (pAttr->AeAttrType)
 	{
 	case AtEnumAttr:
@@ -525,7 +524,7 @@ void TtaSetAttributeValue (Attribute attribute, int value,
 	TtaError (ERR_invalid_attribute_type);
       else if (value < 1)
 	TtaError (ERR_invalid_attribute_value);
-      else if (value > pAttr->AeAttrSSchema->SsAttribute[pAttr->AeAttrNum - 1].AttrNEnumValues)
+      else if (value > pAttr->AeAttrSSchema->SsAttribute->TtAttr[pAttr->AeAttrNum - 1]->AttrNEnumValues)
 	TtaError (ERR_invalid_attribute_value);
       else
 	ok = TRUE;
@@ -582,7 +581,7 @@ void TtaSetAttributeText (Attribute attribute, char* buffer,
       else
 	ClearText (pAttr->AeAttrText);
       /* Sets the new value */
-      CopyStringToText (buffer, pAttr->AeAttrText, &lg);
+      CopyStringToBuffer (buffer, pAttr->AeAttrText, &lg);
       if (pAttr->AeAttrNum == 1)
 	/* language attribute */
 	{
@@ -710,7 +709,7 @@ void TtaGiveAttributeTypeFromName (char *name, Element element,
       else
 	{
 	  pSS = (PtrSSchema)((*attType).AttrSSchema);
-	  switch (pSS->SsAttribute[(*attType).AttrTypeNum - 1].AttrType)
+	  switch (pSS->SsAttribute->TtAttr[(*attType).AttrTypeNum - 1]->AttrType)
 	    {
 	     case AtEnumAttr:
 	       *attrKind = 0;
@@ -767,7 +766,7 @@ void TtaGiveAttributeTypeFromOriginalName (char *name, Element element,
       else
 	{
 	  pSS = (PtrSSchema)((*attType).AttrSSchema);
-	  switch (pSS->SsAttribute[(*attType).AttrTypeNum - 1].AttrType)
+	  switch (pSS->SsAttribute->TtAttr[(*attType).AttrTypeNum - 1]->AttrType)
 	    {
 	    case AtEnumAttr:
 	      *attrKind = 0;
@@ -808,7 +807,7 @@ char *TtaGetAttributeName (AttributeType attType)
 	   attType.AttrTypeNum > ((PtrSSchema) (attType.AttrSSchema))->SsNAttributes)
     TtaError (ERR_invalid_attribute_type);
   else
-    strncpy (bufferName, ((PtrSSchema) (attType.AttrSSchema))->SsAttribute[attType.AttrTypeNum - 1].AttrName, MAX_NAME_LENGTH);
+    strncpy (bufferName, ((PtrSSchema) (attType.AttrSSchema))->SsAttribute->TtAttr[attType.AttrTypeNum - 1]->AttrName, MAX_NAME_LENGTH);
   return bufferName;
 }
 
@@ -831,7 +830,7 @@ char *TtaGetAttributeOriginalName (AttributeType attType)
 	   attType.AttrTypeNum > ((PtrSSchema) (attType.AttrSSchema))->SsNAttributes)
     TtaError (ERR_invalid_attribute_type);
   else
-    strncpy (bufferName, ((PtrSSchema) (attType.AttrSSchema))->SsAttribute[attType.AttrTypeNum - 1].AttrOrigName, MAX_NAME_LENGTH);
+    strncpy (bufferName, ((PtrSSchema) (attType.AttrSSchema))->SsAttribute->TtAttr[attType.AttrTypeNum - 1]->AttrOrigName, MAX_NAME_LENGTH);
   return bufferName;
 }
 
@@ -920,12 +919,12 @@ char *TtaGetAttributeValueOriginalName (AttributeType attType, int value)
   else if (attType.AttrTypeNum < 1 ||
 	   attType.AttrTypeNum > ((PtrSSchema) (attType.AttrSSchema))->SsNAttributes)
     TtaError (ERR_invalid_attribute_type);
-  else if (((PtrSSchema) (attType.AttrSSchema))->SsAttribute[attType.AttrTypeNum - 1].AttrType != AtEnumAttr )
+  else if (((PtrSSchema) (attType.AttrSSchema))->SsAttribute->TtAttr[attType.AttrTypeNum - 1]->AttrType != AtEnumAttr )
     TtaError (ERR_invalid_attribute_type);
-  else if (value < 1 || value > ((PtrSSchema) (attType.AttrSSchema))->SsAttribute[attType.AttrTypeNum - 1].AttrNEnumValues)
+  else if (value < 1 || value > ((PtrSSchema) (attType.AttrSSchema))->SsAttribute->TtAttr[attType.AttrTypeNum - 1]->AttrNEnumValues)
     TtaError (ERR_invalid_parameter);
   else
-    strncpy (bufferName, ((PtrSSchema) (attType.AttrSSchema))->SsAttribute[attType.AttrTypeNum - 1].AttrEnumOrigValue[value - 1], MAX_NAME_LENGTH);
+    strncpy (bufferName, ((PtrSSchema) (attType.AttrSSchema))->SsAttribute->TtAttr[attType.AttrTypeNum - 1]->AttrEnumOrigValue[value - 1], MAX_NAME_LENGTH);
   return bufferName;
 }
 
@@ -949,12 +948,12 @@ char *TtaGetAttributeValueName (AttributeType attType, int value)
   else if (attType.AttrTypeNum < 1 ||
 	   attType.AttrTypeNum > ((PtrSSchema) (attType.AttrSSchema))->SsNAttributes)
     TtaError (ERR_invalid_attribute_type);
-  else if (((PtrSSchema) (attType.AttrSSchema))->SsAttribute[attType.AttrTypeNum - 1].AttrType != AtEnumAttr )
+  else if (((PtrSSchema) (attType.AttrSSchema))->SsAttribute->TtAttr[attType.AttrTypeNum - 1]->AttrType != AtEnumAttr )
     TtaError (ERR_invalid_attribute_type);
-  else if (value < 1 || value > ((PtrSSchema) (attType.AttrSSchema))->SsAttribute[attType.AttrTypeNum - 1].AttrNEnumValues)
+  else if (value < 1 || value > ((PtrSSchema) (attType.AttrSSchema))->SsAttribute->TtAttr[attType.AttrTypeNum - 1]->AttrNEnumValues)
     TtaError (ERR_invalid_parameter);
   else
-    strncpy (bufferName, ((PtrSSchema) (attType.AttrSSchema))->SsAttribute[attType.AttrTypeNum - 1].AttrEnumValue[value - 1], MAX_NAME_LENGTH);
+    strncpy (bufferName, ((PtrSSchema) (attType.AttrSSchema))->SsAttribute->TtAttr[attType.AttrTypeNum - 1]->AttrEnumValue[value - 1], MAX_NAME_LENGTH);
   return bufferName;
 }
 
@@ -972,7 +971,7 @@ char *TtaGetAttributeValueName (AttributeType attType, int value)
 int TtaGetAttributeValueFromOriginalName (char *name,
 					  AttributeType attType)
 {
-  TtAttribute	      *attr;
+  PtrTtAttribute       attr;
   int		       value, i;
 
   UserErrorCode = 0;
@@ -984,11 +983,11 @@ int TtaGetAttributeValueFromOriginalName (char *name,
   else if (attType.AttrTypeNum < 1 ||
 	   attType.AttrTypeNum > ((PtrSSchema) (attType.AttrSSchema))->SsNAttributes)
     TtaError (ERR_invalid_attribute_type);
-  else if (((PtrSSchema) (attType.AttrSSchema))->SsAttribute[attType.AttrTypeNum - 1].AttrType != AtEnumAttr )
+  else if (((PtrSSchema) (attType.AttrSSchema))->SsAttribute->TtAttr[attType.AttrTypeNum - 1]->AttrType != AtEnumAttr )
     TtaError (ERR_invalid_attribute_type);
   else
     {
-      attr = & ((PtrSSchema) (attType.AttrSSchema))->SsAttribute[attType.AttrTypeNum - 1];
+      attr = ((PtrSSchema) (attType.AttrSSchema))->SsAttribute->TtAttr[attType.AttrTypeNum - 1];
       for (i = 0; value == 0 && i < attr->AttrNEnumValues; i++)
 	if (strncmp (attr->AttrEnumOrigValue[i], name, MAX_NAME_LENGTH) == 0)
 	  value = i+1;
@@ -1008,7 +1007,7 @@ int TtaGetAttributeValueFromOriginalName (char *name,
    ---------------------------------------------------------------------- */
 int TtaGetAttributeValueFromName (char *name, AttributeType attType)
 {
-  TtAttribute	      *attr;
+  PtrTtAttribute       attr;
   int		       value, i;
 
   UserErrorCode = 0;
@@ -1020,11 +1019,11 @@ int TtaGetAttributeValueFromName (char *name, AttributeType attType)
   else if (attType.AttrTypeNum < 1 ||
 	   attType.AttrTypeNum > ((PtrSSchema) (attType.AttrSSchema))->SsNAttributes)
     TtaError (ERR_invalid_attribute_type);
-  else if (((PtrSSchema) (attType.AttrSSchema))->SsAttribute[attType.AttrTypeNum - 1].AttrType != AtEnumAttr )
+  else if (((PtrSSchema) (attType.AttrSSchema))->SsAttribute->TtAttr[attType.AttrTypeNum - 1]->AttrType != AtEnumAttr )
     TtaError (ERR_invalid_attribute_type);
   else
     {
-      attr = & ((PtrSSchema) (attType.AttrSSchema))->SsAttribute[attType.AttrTypeNum - 1];
+      attr = ((PtrSSchema) (attType.AttrSSchema))->SsAttribute->TtAttr[attType.AttrTypeNum - 1];
       for (i = 0; value == 0 && i < attr->AttrNEnumValues; i++)
 	if (strncmp(attr->AttrEnumValue[i], name, MAX_NAME_LENGTH) == 0)
 	  value = i+1;
