@@ -12,7 +12,6 @@
  *
  */
 
-#include "ustring.h"
 #include "thot_sys.h"
 #include "libmsg.h"
 #include "message.h"
@@ -229,111 +228,135 @@ static void SetPageIndicators (PtrAbstractBox pAb, PtrAbstractBox table,
   /* A priori la limite de page n'est pas deplacee */
   /* et il faut examiner les paves fils */
   *isPageBreakChanged = FALSE;
+  if (!pAb->AbDead && pAb->AbBox != NULL)
+    {
+      /* verifie les limites de la boite du pave */
+      pBox = pAb->AbBox;
+      isCell = (table != NULL && pBox->BxType == BoCell);
 
-  if (!pAb->AbDead && pAb->AbBox != NULL) {
-     /* verifie les limites de la boite du pave */
-     pBox = pAb->AbBox;
-     isCell = (table != NULL && pBox->BxType == BoCell);
-
-     if (isCell && ThotLocalActions[T_firstcolumn])
+      if (isCell && ThotLocalActions[T_firstcolumn])
         /* page break can be inserted only in the first column */
         (*ThotLocalActions[T_firstcolumn]) (pAb, table, &toContinue);
-     else
-         toContinue = TRUE;
-     if (toContinue) {
-        if (pBox->BxType == BoSplit) {
-           /* --- mis en lignes ------------------------- */
-           pPreviousBox = pBox;
-           pBox = pBox->BxNexChild;
-           pFirstBox = pBox;	/* memorise la premiere boite */
-           /* A priori la boite est dans la page */
-           pAb->AbAfterPageBreak = FALSE;
-           pAb->AbOnPageBreak = FALSE;
-           /* Ce n'est pas la peine de continuer le calcul */
-           /* des coupures de boites quand la limite de    */
-           /* page est deplacee */
-           while (!*isPageBreakChanged && toContinue && pBox != NULL) {
-                 /* Origine de la boite de coupure */
-                 org = pBox->BxYOrg;
+      else
+	toContinue = TRUE;
+      if (toContinue)
+	{
+	  if (pBox->BxType == BoSplit)
+	    {
+	      /* --- mis en lignes ------------------------- */
+	      pPreviousBox = pBox;
+	      pBox = pBox->BxNexChild;
+	      pFirstBox = pBox;	/* memorise la premiere boite */
+	      /* A priori la boite est dans la page */
+	      pAb->AbAfterPageBreak = FALSE;
+	      pAb->AbOnPageBreak = FALSE;
+	      /* Ce n'est pas la peine de continuer le calcul */
+	      /* des coupures de boites quand la limite de    */
+	      /* page est deplacee */
+	      while (!*isPageBreakChanged && toContinue && pBox)
+		{
+		  /* Origine de la boite de coupure */
+		  org = pBox->BxYOrg;
                  if (org + pBox->BxHeight <= *height)
-                    ; /* La boite est a l'interieur de la page */
-                 else if (org >= *height) {
-                      /* Il faut memoriser la boite de coupure coupee */
-                      pBox->BxAbstractBox->AbBox->BxMoved = pBox;
-                      if (pBox == pFirstBox)
-                         /* La boite est hors page */
-                         OutOfPage (pAb, height, isPageBreakChanged);
-                      else if (pPreviousBox->BxType == BoDotted && pPreviousBox->BxNSpaces == 0) {
-                           /* La derniere boite de la page est hyphenee */
-                           /* et n'est pas secable sur un blanc */
-                           if (pPreviousBox == pFirstBox)
-                              /* Le pave est note hors de la page */
-                              OutOfPage (pAb, height, isPageBreakChanged);
-                           else {
+		   ; /* La boite est a l'interieur de la page */
+                 else if (org >= *height)
+		   {
+		     /* Il faut memoriser la boite de coupure coupee */
+		     pBox->BxAbstractBox->AbBox->BxMoved = pBox;
+		     if (pBox == pFirstBox)
+		       /* La boite est hors page */
+		       OutOfPage (pAb, height, isPageBreakChanged);
+		     else if (pPreviousBox->BxType == BoDotted &&
+			      pPreviousBox->BxNSpaces == 0)
+		       {
+			 /* La derniere boite de la page est hyphenee */
+			 /* et n'est pas secable sur un blanc */
+			 if (pPreviousBox == pFirstBox)
+			   /* Le pave est note hors de la page */
+			   OutOfPage (pAb, height, isPageBreakChanged);
+			 else
+			   {
                                 /* deplace la limite de page */
-                                *height = pPreviousBox->BxYOrg;
-                                *isPageBreakChanged = TRUE;
-						   }
-					  } else /* La boite est sur la limite de page */
-                             OnPage (pAb, height, isPageBreakChanged);
-                      toContinue = FALSE;
-				 } else { 
-                        /* La boite est sur la limite de page */
-                        /* deplace la limite de page sur l'origine de la boite */
-                        *height = org;
-                        *isPageBreakChanged = TRUE;
-				 }
+			     *height = pPreviousBox->BxYOrg;
+			     *isPageBreakChanged = TRUE;
+			   }
+		       }
+		     else
+		       /* La boite est sur la limite de page */
+		       OnPage (pAb, height, isPageBreakChanged);
+		     toContinue = FALSE;
+		   }
+		 else
+		   { 
+		     /* La boite est sur la limite de page */
+		     /* deplace la limite de page sur l'origine de la boite */
+		     *height = org;
+		     *isPageBreakChanged = TRUE;
+		   }
 		  
                  pPreviousBox = pBox;
                  pBox = pBox->BxNexChild;
-		   }
-		} else {
-               /* --- cas genenral ----------------------------------------- */
-               /* Si la boite composee n'est pas eclatee */
-               if (pBox->BxType != BoGhost) {
+		}
+	    }
+	  else
+	    {
+	      /* --- cas genenral ----------------------------------------- */
+	      /* Si la boite composee n'est pas eclatee */
+	      if (pBox->BxType != BoGhost)
+		{
                   /* Origine de la boite de coupure */
                   org = pBox->BxYOrg;
-                  if (org + pBox->BxHeight <= *height) {
-                     /* La boite est dans la page */
-                     pAb->AbAfterPageBreak = FALSE;
-                     pAb->AbOnPageBreak = FALSE;
-				  } else if (org >= *height) /* La boite est hors page */
-                         OutOfPage (pAb, height, isPageBreakChanged);
-                  else if (!pAb->AbAcceptPageBreak || pAb->AbLeafType == LtText || pAb->AbLeafType == LtSymbol) {
-                       /* La boite est sur la limite de page mais non secable */
-                       /* deplace la limite de page sur l'origine de la boite */
-                       *height = org;
-                       *isPageBreakChanged = TRUE;
-				  } else if (pAb->AbVertEnclosing) {
-                         /* La boite est sur la limite de page, secable et englobee */
-                         if (pAb->AbFirstEnclosed == NULL)
-                            /* attend la boite terminale pour remonter l'indicateur */
-                            OnPage (pAb, height, isPageBreakChanged);
-				  } else {
-                         /* La boite est sur la limite de page, secable et non englobee */
-                         pAb->AbOnPageBreak = TRUE;
-                         pAb->AbAfterPageBreak = FALSE;
-				  }
-			   } else { /*if != BoGhost */
-                      pAb->AbOnPageBreak = FALSE;
-                      pAb->AbAfterPageBreak = FALSE;
-			   }
+                  if (org + pBox->BxHeight <= *height)
+		    {
+		      /* La boite est dans la page */
+		      pAb->AbAfterPageBreak = FALSE;
+		      pAb->AbOnPageBreak = FALSE;
+		    }
+		  else if (org >= *height) /* La boite est hors page */
+		    OutOfPage (pAb, height, isPageBreakChanged);
+                  else if (!pAb->AbAcceptPageBreak || pAb->AbLeafType == LtText
+			   || pAb->AbLeafType == LtSymbol)
+		    {
+		      /* La boite est sur la limite de page mais non secable */
+		      /* deplace la limite de page sur l'origine de la boite */
+		      *height = org;
+		      *isPageBreakChanged = TRUE;
+		    }
+		  else if (pAb->AbVertEnclosing)
+		    {
+		      /* La boite est sur la limite de page, secable et englobee */
+		      if (pAb->AbFirstEnclosed == NULL)
+			/* attend la boite terminale pour remonter l'indicateur */
+			OnPage (pAb, height, isPageBreakChanged);
+		    }
+		  else
+		    {
+		      /* La boite est sur la limite de page, secable et non englobee */
+		      pAb->AbOnPageBreak = TRUE;
+		      pAb->AbAfterPageBreak = FALSE;
+		    }
+		} else
+		  { /*if != BoGhost */
+		    pAb->AbOnPageBreak = FALSE;
+		    pAb->AbAfterPageBreak = FALSE;
+		  }
 	      
-               /* traite les paves fils */
-               pChildAb = pAb->AbFirstEnclosed;
-               if (pAb->AbBox->BxType == BoTable)
-                  table = pAb;
-               /* Ce n'est pas la peine de continuer le calcul */
-               /* des coupures de boites quand la limite de    */
-               /* page est deplacee */
-               while (pChildAb != NULL && !*isPageBreakChanged) {
-                            SetPageIndicators (pChildAb, table, height, isPageBreakChanged);
-                            /* passe au suivant */
-                            pChildAb = pChildAb->AbNext;
-			   }
+	      /* traite les paves fils */
+	      pChildAb = pAb->AbFirstEnclosed;
+	      if (pAb->AbBox->BxType == BoTable)
+		table = pAb;
+	      /* Ce n'est pas la peine de continuer le calcul */
+	      /* des coupures de boites quand la limite de    */
+	      /* page est deplacee */
+	      while (pChildAb && !*isPageBreakChanged)
+		{
+		  SetPageIndicators (pChildAb, table, height, isPageBreakChanged);
+		  /* passe au suivant */
+		  pChildAb = pChildAb->AbNext;
 		}
-	 }
-  }
+	    }
+	}
+    }
 }
 
 
