@@ -1,19 +1,10 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
-/*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
 /*
  * hyphen.c :  gestion de la coupure des mots
  *
@@ -22,23 +13,52 @@
  *
  */
 
-#include "ustring.h"
 #include "thot_sys.h"
+#include "ustring.h"
 #include "constmedia.h"
 #include "typemedia.h"
-#include "language.h"
 #include "dictionary.h"
+#include "language.h"
 
 #define THOT_EXPORT extern
 #include "boxes_tv.h"
 
-static CHAR_T         sepcar[] =
+static CHAR_T sepcar[] =
 {
-   TEXT(' '), TEXT('.'), TEXT(','), TEXT('`'), '\47', TEXT('-'), TEXT(';'), TEXT(':'), TEXT('['), TEXT(']'), TEXT('('), TEXT(')'), TEXT('{'), TEXT('}'), TEXT('<'), TEXT('>'),
-   TEXT('/'), TEXT('!'), TEXT('?'), '\240', '\241', '\277', '\253', '\273', '\212', TEXT('"'), '\201', '\202'
+ TEXT(' '), TEXT('.'), TEXT(','), TEXT('`'), TEXT('\47'), TEXT('-'),
+ TEXT(';'), TEXT(':'), TEXT('['), TEXT(']'), TEXT('('), TEXT(')'),
+ TEXT('{'), TEXT('}'), TEXT('<'), TEXT('>'), TEXT('/'), TEXT('!'),
+ TEXT('?'), TEXT('\n'), TEXT('\240'), TEXT('\241'), TEXT('\277'),
+ TEXT('\253'), TEXT('\273'), TEXT('\212'), TEXT('"'), TEXT('\201'),
+ TEXT('\202')
 };
 
 #include "font_f.h"
+#include "language_f.h"
+#include "memory_f.h"
+#include "uconvert_f.h"
+#include "ustring_f.h"
+
+
+/*----------------------------------------------------------------------
+   SmallLettering convertit les caracte`res majuscules en minuscules.   
+  ----------------------------------------------------------------------*/
+void SmallLettering (unsigned char *word)
+{
+  unsigned char c;
+  int           j;
+
+  j = 0;
+  while (word[j] != 0)
+    {
+      c = word[j];
+      if (c >= 65 && c <= 90)
+	word[j] = c + 32;		/* Majuscules */
+      else if (c >= 192 && c <= 222)
+	word[j] = c + 32;		/* Majuscules accentue'es */
+      j++;
+    }
+}
 
 /*----------------------------------------------------------------------
    PatternHyphen  cherche pour le mot word le premier point de     
@@ -49,25 +69,22 @@ static CHAR_T         sepcar[] =
    Si la coupure est possible, indique dans addHyphen s'il 
    faut inse'rer un tiret a` la position de coupure ou non.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static int          PatternHyphen (STRING word, int length, Language language, ThotBool * addHyphen)
-#else  /* __STDC__ */
-static int          PatternHyphen (word, length, language, addHyphen)
-STRING              word;
-int                 length;
-Language            language;
-ThotBool           *addHyphen;
-
-#endif /* __STDC__ */
+static int PatternHyphen (STRING word, int length, Language language,
+			  ThotBool *addHyphen)
 {
-   int                 i, k;
-   int                 status;
-   int                *pHyphen;
+  char               *iso;
+  int                 i, k;
+  int                 status;
+  int                *pHyphen;
 
    *addHyphen = FALSE;
    status = 0;
-
-   pHyphen = TtaGetPatternHyphenList (word, language);
+   /* current patterns concern only iso-latin characters */
+   iso = TtaConvertCHARToIso (word, ISO_8859_1);
+   /* Convertit le mot en minuscule */
+   SmallLettering (iso);
+   pHyphen = TtaGetPatternHyphenList (iso, language);
+   TtaFreeMemory (iso);
    if (pHyphen == NULL)
       /* Pas de point de coupure */
       return status;
@@ -93,51 +110,20 @@ ThotBool           *addHyphen;
    retourne TRUE si c'est un separateur               
    FALSE sinon                               
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            IsSeparatorChar (CHAR_T c)
-#else  /* __STDC__ */
-ThotBool            IsSeparatorChar (c)
-CHAR_T                c;
-#endif /* __STDC__ */
+ThotBool IsSeparatorChar (CHAR_T c)
 {
    int              i, lg;
-
+   
    lg = sizeof (sepcar);
    for (i = 0; i < lg; i++)
      {
-	if (c == sepcar[i])
-	   return (TRUE);
+       if (c == sepcar[i])
+	 return (TRUE);
      }
    return (FALSE);
 }
 
 
-/*----------------------------------------------------------------------
-   SmallLettering convertit les caracte`res majuscules en minuscules.   
-  ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                SmallLettering (STRING word)
-#else  /* __STDC__ */
-void                SmallLettering (word)
-STRING              word;
-#endif /* __STDC__ */
-{
-   UCHAR_T       c;
-   int                 j;
-
-   j = 0;
-   while (word[j] != 0)
-     {
-	c = word[j];
-	if (c >= 65 && c <= 90)
-	   word[j] = (CHAR_T) (c + 32);		/* Majuscules */
-	else if (c >= 192 && c <= 222)
-	   word[j] = (CHAR_T) (c + 32);		/* Majuscules accentue'es */
-	j++;
-     }
-}
-
-
 /*----------------------------------------------------------------------
    NextWord isole le mot suivant dans la suite des buffers de      
    de texte. Ce mot peut e^tre vide.                       
@@ -150,23 +136,14 @@ STRING              word;
    - la longueur des se'parateurs qui pre'ce`dent le       
    de'but du mot.                                        
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static int          NextWord (ptrfont font, PtrTextBuffer * buffer, int *rank, CHAR_T word[THOT_MAX_CHAR], int *width)
-
-#else  /* __STDC__ */
-static int          NextWord (font, buffer, rank, word, width)
-ptrfont             font;
-PtrTextBuffer      *buffer;
-int                *rank;
-CHAR_T                word[THOT_MAX_CHAR];
-int                *width;
-#endif /* __STDC__ */
+static int NextWord (SpecFont font, PtrTextBuffer *buffer, int *rank,
+		     CHAR_T *word, int *width)
 {
+   PtrTextBuffer       adbuff;
    int                 i, j;
    int                 lg, nbChars;
    ThotBool            still;
    ThotBool            changedebut;
-   PtrTextBuffer       adbuff;
 
    /* Initialisations */
    word[0] = EOS;
@@ -203,10 +180,10 @@ int                *width;
 		if (j <= 1)
 		  {
 		     changedebut = TRUE;
-		     lg += CharacterWidth ((UCHAR_T) word[j], font);
+		     lg += BoxCharacterWidth (word[j], font);
 		     if (j == 1)
 			/* Il faut comptabiliser le caractere precedent */
-			lg += CharacterWidth ((UCHAR_T) word[j - 1], font);
+			lg += BoxCharacterWidth (word[j - 1], font);
 		     nbChars += j + 1;
 		     j = 0;
 		  }
@@ -224,7 +201,7 @@ int                *width;
 		    {
 		       /* Le debut du mot est deplace */
 		       changedebut = TRUE;
-		       lg += CharacterWidth ((UCHAR_T) word[j], font);
+		       lg += BoxCharacterWidth (word[j], font);
 		       nbChars++;
 		    }
 	       }
@@ -262,21 +239,11 @@ int                *width;
    Rend un indicateur qui vaut VRAI s'il faut engendrer un 
    tiret d'hyphe'nation.                                   
    Le parame`tre language donne l'indice de la langue dans 
-   la table des langues courante.                          
+   la table des langues courante.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static int          WordHyphen (STRING word, int length, Language language, ThotBool * hyphen)
-#else  /* __STDC__ */
-static int          WordHyphen (word, length, language, hyphen)
-STRING              word;
-int                 length;
-Language            language;
-ThotBool           *hyphen;
-#endif /* __STDC__ */
+static int WordHyphen (STRING word, int length, Language language,
+		       ThotBool *hyphen)
 {
-
-   /* Convertit le mot en minuscule */
-   SmallLettering (word);
    return PatternHyphen (word, length, language, hyphen);
 }
 
@@ -294,115 +261,105 @@ ThotBool           *hyphen;
    - un indicateur qui vaut VRAI s'il faut engendrer un    
    tiret d'hyphe'nation.                                 
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-int                 HyphenLastWord (ptrfont font, Language language, PtrTextBuffer * buffer, int *rank, int *width, ThotBool * hyphen)
-#else  /* __STDC__ */
-int                 HyphenLastWord (font, language, buffer, rank, width, hyphen)
-ptrfont             font;
-Language            language;
-PtrTextBuffer      *buffer;
-int                *rank;
-int                *width;
-ThotBool           *hyphen;
-#endif /* __STDC__ */
+int HyphenLastWord (SpecFont font, Language language, PtrTextBuffer *buffer,
+		    int *rank, int *width, ThotBool *hyphen)
 {
-   PtrTextBuffer       adbuff;
-   int                 i, lghyphen;
-   int                 longueur, nbChars;
-   int                 largeur, charWidth;
-   int                 longretour, lgreste;
-   int                 wordLength;
-   CHAR_T                mot[THOT_MAX_CHAR];
+  PtrTextBuffer       adbuff;
+  CHAR_T              word[THOT_MAX_CHAR];
+  int                 i, lghyphen;
+  int                 length, nbChars;
+  int                 w, charWidth;
+  int                 retLength, rest;
+  int                 wordLength;
 
-   /* Si la coupure de mots est active */
-   longretour = 0;
-   *hyphen = FALSE;
+  /* Si la coupure de words est active */
+  retLength = 0;
+  *hyphen = FALSE;
+  if (*width > 0 && *buffer != NULL)
+    {
+      /* La position du debut du word */
+      adbuff = *buffer;
+      i = *rank - 1;
+      if (i >= adbuff->BuLength)
+	{
+	  if (adbuff->BuNext != NULL)
+	    {
+	      i = 0;
+	      adbuff = adbuff->BuNext;
+	    }
+	  else
+	    return retLength;
+	}
 
-   if (*width > 0 && *buffer != NULL)
-     {
-	/* La position du debut du mot */
-	adbuff = *buffer;
+      /* Length et largeur des separateurs avant le word */
+      nbChars = NextWord (font, &adbuff, &i, word, &w);
+      /* Largeur du tiret d'hyphenantion */
+      lghyphen = BoxCharacterWidth (173, font);
+      /* Espace restant dans la ligne */
+      rest = *width - w - lghyphen;
+      /* Nombre de carateres maximum du word pouvant entrer dans la ligne */
+      if (word != NULL)
+	/* On a isole un word assez long */
+	wordLength = ustrlen (word);	/* nombre de caraceteres du word isole */
+      if (wordLength > 4 && rest > 0)
+	{
+	  /* Recherche le nombre de caracteres du word qui rentrent */
+	  /* dans la ligne */
+	  length = 0;
+	  charWidth = BoxCharacterWidth (word[length], font);
+	  while (rest >= charWidth && length < wordLength)
+	    {
+	      rest -= charWidth;
+	      length++;
+	      charWidth = BoxCharacterWidth (word[length], font);
+	    }
 
-	i = *rank - 1;
-	if (i >= adbuff->BuLength)
-	   if (adbuff->BuNext != NULL)
-	     {
-		i = 0;
-		adbuff = adbuff->BuNext;
-	     }
-	   else
-	      return longretour;
-
-	/* Longueur et largeur des separateurs avant le mot */
-	nbChars = NextWord (font, &adbuff, &i, mot, &largeur);
-	/* Largeur du tiret d'hyphenantion */
-	lghyphen = CharacterWidth (173, font);
-	/* Espace restant dans la ligne */
-	lgreste = *width - largeur - lghyphen;
-	/* Nombre de carateres maximum du mot pouvant entrer dans la ligne */
-
-	if (mot != NULL)
-	   /* On a isole un mot assez long */
-	   wordLength = ustrlen (mot);	/* nombre de caraceteres du mot isole */
-	if (wordLength > 4 && lgreste > 0)
-	  {
-	     /* Recherche le nombre de caracteres du mot qui rentrent */
-	     /* dans la ligne */
-	     longueur = 0;
-	     charWidth = CharacterWidth ((UCHAR_T) mot[longueur], font);
-	     while (lgreste >= charWidth && longueur < wordLength)
-	       {
-		  lgreste -= charWidth;
-		  longueur++;
-		  charWidth = CharacterWidth ((UCHAR_T) mot[longueur], font);
-	       }
-
-	     if (longueur > 1)
-	       {
-		  /* Recherche un point de coupure pour le mot */
-		  longueur = WordHyphen (mot, longueur, language, hyphen);
-		  if (longueur > 0)
+	  if (length > 1)
+	    {
+	      /* Recherche un point de coupure pour le word */
+	      length = WordHyphen (word, length, language, hyphen);
+	      if (length > 0)
+		{
+		  /* On a trouve un point de coupure */
+		  if (*hyphen)
+		    *width = w + lghyphen; /* 1ere partie du word */
+		  else
+		    *width = w;	/* 1ere partie du word */
+		  /* number of characters */
+		  retLength = length + nbChars;
+		  while (length > 0)
 		    {
-		       /* On a trouve un point de coupure */
-		       if (*hyphen)
-			  *width = largeur + lghyphen;	/* 1ere partie du mot */
-		       else
-			  *width = largeur;	/* 1ere partie du mot */
-
-		       longretour = longueur + nbChars;	/* nombre de caracteres */
-		       while (longueur > 0)
-			 {
-			    if (i >= adbuff->BuLength)
-			      {
-				 /* Il faut changer de buffer */
-				 adbuff = adbuff->BuNext;
-				 i = 0;
-			      }
-			    else
-			      {
-				 /* comptabilise le caractere */
-				 longueur--;
-				 *width += CharacterWidth ((UCHAR_T) (adbuff->BuContent[i++]), font);
-			      }
-			 }	/*while */
-
-		       /* Indice dans le buffer 2eme partie du mot */
-		       if (i >= adbuff->BuLength)
-			 {
-			    /* Il faut changer de buffer */
-			    i++;
-			    /* nouvelle position */
-			    *rank = i - adbuff->BuLength;
-			    adbuff = adbuff->BuNext;
-			 }
-		       else
-			  *rank = i + 1;
-		       *buffer = adbuff;
+		      if (i >= adbuff->BuLength)
+			{
+			  /* Il faut changer de buffer */
+			  adbuff = adbuff->BuNext;
+			  i = 0;
+			}
+		      else
+			{
+			  /* comptabilise le caractere */
+			  length--;
+			  *width += BoxCharacterWidth (adbuff->BuContent[i++], font);
+			}
 		    }
-	       }
-	  }
-     }
-   return longretour;
+		  
+		  /* Indice dans le buffer 2eme partie du word */
+		  if (i >= adbuff->BuLength)
+		    {
+		      /* Il faut changer de buffer */
+		      i++;
+		      /* nouvelle position */
+		      *rank = i - adbuff->BuLength;
+		      adbuff = adbuff->BuNext;
+		    }
+		  else
+		    *rank = i + 1;
+		  *buffer = adbuff;
+		}
+	    }
+	}
+    }
+  return retLength;
 }
 
 
@@ -411,12 +368,7 @@ ThotBool           *hyphen;
    coupure des mots et l'autorisation de coupure pour la   
    boi^te donne'e.                                         
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            CanHyphen (PtrBox pBox)
-#else  /* __STDC__ */
-ThotBool            CanHyphen (pBox)
-PtrBox              pBox;
-#endif /* __STDC__ */
+ThotBool CanHyphen (PtrBox pBox)
 {
   Language            language;
 
@@ -432,8 +384,6 @@ PtrBox              pBox;
 	  if (language == 0)
 	    /* On saute la langue ISOlatin-1 */
 	    return FALSE;
-	  /*   else if (language == TtaGetLanguageIdFromName("Fran\347ais")) */
-	  /*      return TRUE; */
 	  else if (TtaGetPrincipalDictionary (language) != NULL)
 	    /* Traitement par le dictionnaire de la langue */
 	    return TRUE;
